@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Jakub Kurzak
  * @author Hatem Ltaief
  * @date 2010-11-15
@@ -42,9 +42,8 @@ void plasma_pzgeqrfrh_quark(PLASMA_desc A, PLASMA_desc T, int BS,
     K = min(A.mt, A.nt);
     for (k = 0; k < K; k++) {
         tempkn = k == A.nt-1 ? A.n-k*A.nb : A.nb;
-//      for (M = k; M < A.mt; M += BS) {
         for (M = k;
-             M < A.mt-1 || M == k;  // No bottom single-row subdomain
+             M < A.mt-1 || M == k;  /* No bottom single-row subdomain */
              M += BS) {
             tempMm = M == A.mt-1 ? A.m-M*A.mb : A.mb;
             ldaM = BLKLDD(A, M);
@@ -64,9 +63,8 @@ void plasma_pzgeqrfrh_quark(PLASMA_desc A, PLASMA_desc T, int BS,
                     T(M, k), T.mb,
                     A(M, n), ldaM);
             }
-//          for (m = M+1; m < M+BS && m < A.mt; m++) {
             for (m = M+1;
-                 (m < M+BS && m < A.mt) || m == A.mt-1; // Suck in bottom single-row domain
+                 (m < M+BS && m < A.mt) || m == A.mt-1; /* Suck in bottom single-row domain */
                  m++) {
                 tempmm = m == A.mt-1 ? A.m-m*A.mb : A.mb;
                 ldam = BLKLDD(A, m);
@@ -91,9 +89,8 @@ void plasma_pzgeqrfrh_quark(PLASMA_desc A, PLASMA_desc T, int BS,
             }
         }
         for (RD = BS; RD < A.mt-k; RD *= 2) {
-//          for (M = k; M+RD < A.mt; M += 2*RD) {
             for (M = k;
-                 M+RD < A.mt-1; // No reduction with bottom single-row subdomain
+                 M+RD < A.mt-1; /* No reduction with bottom single-row subdomain */
                  M += 2*RD) {
                 tempMRDm = M+RD == A.mt-1 ? A.m-(M+RD)*A.mb : A.mb;
                 ldaM   = BLKLDD(A, M   );
