@@ -10,7 +10,7 @@
  *  based on the GKK algorithm by Gustavson, Karlsson, Kagstrom
  *  and its fortran implementation.
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Mathieu Faverge
  * @date 2010-11-15
  *
@@ -25,33 +25,16 @@
  *
  * plasma_pzgetmi2 - realises nprob independant transpositions. Each
  * subproblem is a tile of mb-by-nb elements.
- * This function use an extra space of PLASMA_SIZE*(mb*nb). This is a
- * maximum in case of dynamic scheduling.
- * 
+ * This function use an extra space of PLASMA_SIZE*(mb*nb).
  *
  *******************************************************************************
  *
- * @param[in] dep. Used only in dynamic scheduling.
- *       PlasmaIPT_Nodep: No fake dependencies are added.
- *       PlasmaIPT_Panel: A gatherv is added on each panel and panel size is m*nb.
- *       PlasmaIPT_All:   A gatherv is added on the whole matrix.
+ * @param[in] plasma
+ *          Plasma context to which this call belong to.
  *
- * @param[in] m
- *       Number of row of A if tiles are sorted in column major format,
- *       number of columns otherwise.
+ *******************************************************************************
  *
- * @param[in] n
- *       Number of columns of A if tiles are sorted in column major format,
- *       number of rows otherwise.
- *
- * @param[in] mb
- *       Number of rows/columns in each individual subproblem. m%mb must be 0.
- *
- * @param[in] nb
- *       Number of columns/rows in each individual subproblem. n%nb must be 0.
- *
- * @param[in,out] A
- *       Matrix of size m*n.
+ * @sa plasma_pzgetmi2_quark
  *
  ******************************************************************************/
 void plasma_pzgetmi2(plasma_context_t *plasma) {
@@ -85,7 +68,65 @@ void plasma_pzgetmi2(plasma_context_t *plasma) {
     plasma_private_free(plasma, work);
 }
 
-void plasma_pzgetmi2_quark(PLASMA_enum idep, PLASMA_enum odep, PLASMA_enum storev, int m, int n, int mb, int nb, PLASMA_Complex64_t *A,
+/** ****************************************************************************
+ *
+ * @ingroup InPlaceTransformation
+ *
+ * plasma_pzgetmi2_quark - realises nprob independant transpositions. Each
+ * subproblem is a tile of mb-by-nb elements.
+ * This function use an extra space of PLASMA_SIZE*(mb*nb). This is a
+ * maximum in case of dynamic scheduling.
+ * 
+ *
+ *******************************************************************************
+ *
+ * @param[in] idep
+ *       PlasmaIPT_Nodep: No fake dependencies are added.
+ *       PlasmaIPT_Panel: A gatherv is added on each panel and panel size is m*nb.
+ *       PlasmaIPT_All:   A gatherv is added on the whole matrix.
+ *
+ * @param[in] odep
+ *       PlasmaIPT_Nodep: No fake dependencies are added.
+ *       PlasmaIPT_Panel: A gatherv is added on each panel and panel size is m*nb.
+ *       PlasmaIPT_All:   A gatherv is added on the whole matrix.
+ *
+ * @param[in] storev
+ *       PlasmaColumnWise: Data stored in column major.
+ *       PlasmaRowWise: Data stored in row major.
+ *
+ * @param[in] m
+ *       Number of row of A if tiles are sorted in column major format,
+ *       number of columns otherwise.
+ *
+ * @param[in] n
+ *       Number of columns of A if tiles are sorted in column major format,
+ *       number of rows otherwise.
+ *
+ * @param[in] mb
+ *       Number of rows in each individual subproblem if storev == PlasmaColumnWise, 
+ *       number of columns otherwise. m%mb must be 0.
+ *
+ * @param[in] nb
+ *       Number of columns in each individual subproblem if storev == PlasmaColumnWise, 
+ *       number of rows otherwise. n%nb must be 0.
+ *
+ * @param[in,out] A
+ *       Matrix of size m*n.
+ *
+ * @param[in] sequence
+ *          Identifies the sequence of function calls that this call belongs to
+ *          (for completion checks and exception handling purposes).
+ *
+ * @param[out] request
+ *          Identifies this function call (for exception handling purposes).
+ *
+ *******************************************************************************
+ *
+ * @sa plasma_pzgetmi2
+ *
+ ******************************************************************************/
+void plasma_pzgetmi2_quark(PLASMA_enum idep, PLASMA_enum odep, PLASMA_enum storev, 
+                           int m, int n, int mb, int nb, PLASMA_Complex64_t *A,
                            PLASMA_sequence *sequence, PLASMA_request *request)
 {
     plasma_context_t *plasma;
