@@ -10,7 +10,7 @@
  *  based on the GKK algorithm by Gustavson, Karlsson, Kagstrom
  *  and its fortran implementation.
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Mathieu Faverge
  * @date 2010-11-15
  *
@@ -74,6 +74,10 @@ void plasma_pzpack(plasma_context_t *plasma)
     if (sequence->status != PLASMA_SUCCESS)
         return;
 
+    /* Quick return */
+    if ( n <= 1 )
+      return;
+
     m1 = m - m0;
 
     size = PLASMA_SIZE;
@@ -172,6 +176,10 @@ void plasma_pzunpack(plasma_context_t *plasma)
     if (sequence->status != PLASMA_SUCCESS)
         return;
 
+    /* Quick return */
+    if ( n <= 1 )
+      return;
+
     m1 = m - m0;
 
     size = PLASMA_SIZE;
