@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Hatem Ltaief
  * @author Jakub Kurzak
  * @author Mathieu Faverge
@@ -30,7 +30,8 @@ void plasma_pzunglq_quark(PLASMA_desc A, PLASMA_desc Q, PLASMA_desc T,
 
     int k, m, n;
     int ldak, ldqm;
-    int tempnn, tempmm, tempkm, tempkn;
+    int tempnn, tempmm, tempkmin, tempkn;
+    int tempAkm, tempAkn;
     int ib;
 
     plasma = plasma_context_self();
@@ -40,8 +41,10 @@ void plasma_pzunglq_quark(PLASMA_desc A, PLASMA_desc Q, PLASMA_desc T,
 
     ib = PLASMA_IB;
     for (k = min(A.mt, A.nt)-1; k >= 0; k--) {
-        tempkm = k == A.mt-1 ? A.m-k*A.mb : A.mb;
-        tempkn = k == A.nt-1 ? A.n-k*A.nb : A.nb;
+        tempAkm  = k == A.mt-1 ? A.m-k*A.mb : A.mb;
+        tempAkn  = k == A.nt-1 ? A.n-k*A.nb : A.nb;
+        tempkmin = min( tempAkn, tempAkm );
+        tempkn   = k == Q.nt-1 ? Q.n-k*Q.nb : Q.nb;
         ldak = BLKLDD(A, k);
         for (n = Q.nt-1; n > k; n--) {
             tempnn = n == Q.nt-1 ? Q.n-n*Q.nb : Q.nb;
@@ -51,7 +54,7 @@ void plasma_pzunglq_quark(PLASMA_desc A, PLASMA_desc Q, PLASMA_desc T,
                 QUARK_CORE_ztsmlq(
                     plasma->quark, &task_flags,
                     PlasmaRight, PlasmaNoTrans,
-                    tempmm, A.nb, tempmm, tempnn, tempkm, ib, T.nb,
+                    tempmm, Q.nb, tempmm, tempnn, tempAkm, ib, T.nb,
                     Q(m, k), ldqm,
                     Q(m, n), ldqm,
                     A(k, n), ldak,
@@ -64,7 +67,7 @@ void plasma_pzunglq_quark(PLASMA_desc A, PLASMA_desc Q, PLASMA_desc T,
             QUARK_CORE_zunmlq(
                 plasma->quark, &task_flags,
                 PlasmaRight, PlasmaNoTrans,
-                tempmm, tempkn, tempkm, ib, T.nb,
+                tempmm, tempkn, tempkmin, ib, T.nb,
                 A(k, k), ldak,
                 T(k, k), T.mb,
                 Q(m, k), ldqm);
