@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Emmanuel Agullo
  * @date 2010-11-15
  * @precisions mixed zc -> ds
@@ -138,13 +138,13 @@
  *
  * @param[out] X
  *          If return value = 0, the solution vectors, stored columnwise.
- *          if M >= N, rows 1 to N of B contain the least squares solution vectors; the residual
+ *          if M >= N, rows 1 to N of X contain the least squares solution vectors; the residual
  *          sum of squares for the solution in each column is given by the sum of squares of the
  *          modulus of elements N+1 to M in that column;
- *          if M < N, rows 1 to N of B contain the minimum norm solution vectors;
+ *          if M < N, rows 1 to N of X contain the minimum norm solution vectors;
  *
  * @param[in] LDX
- *          The leading dimension of the array B. LDB >= MAX(1,M,N).
+ *          The leading dimension of the array X. LDX >= MAX(1,M,N).
  *
  * @param[out] ITER
  *          The number of the current iteration in the iterative refinement process
@@ -359,6 +359,21 @@ int PLASMA_zcgels(PLASMA_enum trans, int M, int N, int NRHS,
  *          modulus of elements N+1 to M in that column;
  *          if M < N, rows 1 to N of B contain the minimum norm solution vectors;
  *
+ * @param[in] B
+ *          The descriptor of the M-by-NRHS matrix B of right hand side vectors, stored columnwise. Not modified.
+ *
+ * @param[in,out] X
+ *          On entry, it's only the descriptor where to store the result.
+ *          On exit, if return value = 0, X is the solution vectors, stored columnwise:
+ *          if M >= N, rows 1 to N of X contain the least squares solution vectors; the residual
+ *          sum of squares for the solution in each column is given by the sum of squares of the
+ *          modulus of elements N+1 to M in that column;
+ *          if M < N, rows 1 to N of X contain the minimum norm solution vectors;
+ *
+ * @param[out] ITER
+ *          If > 0, ITER is the number of the current iteration in the iterative refinement process.
+ *          -ITERMAX-1, if the refinment step failed and the double precision factorization has been used.
+ *       
  *******************************************************************************
  *
  * @return
@@ -448,6 +463,20 @@ int PLASMA_zcgels_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, PLASMA_desc *T,
         plasma_fatal_error("PLASMA_zcgels_Tile", "PLASMA not initialized");
         return PLASMA_ERR_NOT_INITIALIZED;
     }
+    if (sequence == NULL) {
+        plasma_fatal_error("PLASMA_zcgels_Tile", "NULL sequence");
+        return PLASMA_ERR_UNALLOCATED;
+    }
+    if (request == NULL) {
+        plasma_fatal_error("PLASMA_zcgels_Tile", "NULL request");
+        return PLASMA_ERR_UNALLOCATED;
+    }
+    /* Check sequence status */
+    if (sequence->status == PLASMA_SUCCESS)
+        request->status = PLASMA_SUCCESS;
+    else
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
+
     /* Check descriptors for correctness */
     if (plasma_desc_check(&descA) != PLASMA_SUCCESS) {
         plasma_error("PLASMA_zcgels_Tile", "invalid first descriptor");
@@ -551,16 +580,15 @@ int PLASMA_zcgels_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, PLASMA_desc *T,
 
     /* Convert B from double precision to single precision and store
        the result in SX. */
-
     PLASMA_zlag2c(descB, descSX);
+    if (sequence->status != PLASMA_SUCCESS)
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
 
     /* Convert A from double precision to single precision and store
        the result in SA. */
-
     PLASMA_zlag2c(descA, descSA);
-
-    /* Set INFO to ZERO */
-    PLASMA_INFO = PLASMA_SUCCESS;
+    if (sequence->status != PLASMA_SUCCESS)
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
 
     if (descSA.m >= descSA.n) {
 
@@ -660,7 +688,7 @@ int PLASMA_zcgels_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, PLASMA_desc *T,
         plasma_desc_mat_free(&descSX);
         plasma_desc_mat_free(&descR);
         plasma_shared_free(plasma, work);
-        return PLASMA_INFO;
+        return PLASMA_SUCCESS;
     }
 
     printf("Rnorm=%e, Xnorm * cte=%e, Rnorm=%e, cte=%e\n", Rnorm, Xnorm * cte, Rnorm, cte);
@@ -751,7 +779,7 @@ int PLASMA_zcgels_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, PLASMA_desc *T,
             plasma_desc_mat_free(&descSX);
             plasma_desc_mat_free(&descR);
             plasma_shared_free(plasma, work);
-            return PLASMA_INFO;
+            return PLASMA_SUCCESS;
         }
     }
 
