@@ -6,8 +6,9 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Emmanuel Agullo
+ * @author Mathieu Faverge
  * @date 2010-11-15
  * @precisions mixed zc -> ds
  *
@@ -57,6 +58,89 @@
                          PLASMA_sequence*,   sequence,	\
                          PLASMA_request*,    request)
 
+
+#define PLASMA_zgetrs(_A, _IPIV, _X)                                    \
+    {                                                                   \
+        plasma_dynamic_call_3(                                          \
+            plasma_pzbarrier_tl2pnl,                                    \
+            PLASMA_desc, (_X),                                          \
+            PLASMA_sequence*, sequence,                                 \
+            PLASMA_request*,  request);                                 \
+                                                                        \
+        plasma_dynamic_call_5(                                          \
+            plasma_pzlaswp,                                             \
+            PLASMA_desc, (_X),                                          \
+            int *,       (_IPIV),                                       \
+            int,         1,                                             \
+            PLASMA_sequence*, sequence,                                 \
+            PLASMA_request*,  request);                                 \
+                                                                        \
+        plasma_parallel_call_9(                                         \
+            plasma_pztrsm,                                              \
+            PLASMA_enum, PlasmaLeft,                                    \
+            PLASMA_enum, PlasmaLower,                                   \
+            PLASMA_enum, PlasmaNoTrans,                                 \
+            PLASMA_enum, PlasmaUnit,                                    \
+            PLASMA_Complex64_t, 1.0,                                    \
+            PLASMA_desc, (_A),                                          \
+            PLASMA_desc, (_X),                                          \
+            PLASMA_sequence*, sequence,                                 \
+            PLASMA_request*, request);                                  \
+                                                                        \
+        plasma_parallel_call_9(                                         \
+            plasma_pztrsm,                                              \
+            PLASMA_enum, PlasmaLeft,                                    \
+            PLASMA_enum, PlasmaUpper,                                   \
+            PLASMA_enum, PlasmaNoTrans,                                 \
+            PLASMA_enum, PlasmaNonUnit,                                 \
+            PLASMA_Complex64_t, 1.0,                                    \
+            PLASMA_desc, (_A),                                          \
+            PLASMA_desc, (_X),                                          \
+            PLASMA_sequence*, sequence,                                 \
+            PLASMA_request*, request);                                  \
+    }
+
+#define PLASMA_cgetrs(_A, _IPIV, _X)                                    \
+    {                                                                   \
+        plasma_dynamic_call_3(                                          \
+            plasma_pcbarrier_tl2pnl,                                    \
+            PLASMA_desc, (_X),                                          \
+            PLASMA_sequence*, sequence,                                 \
+            PLASMA_request*,  request);                                 \
+                                                                        \
+        plasma_dynamic_call_5(                                          \
+            plasma_pclaswp,                                             \
+            PLASMA_desc, (_X),                                          \
+            int *,       (_IPIV),                                       \
+            int,         1,                                             \
+            PLASMA_sequence*, sequence,                                 \
+            PLASMA_request*,  request);                                 \
+                                                                        \
+        plasma_parallel_call_9(                                         \
+            plasma_pctrsm,                                              \
+            PLASMA_enum, PlasmaLeft,                                    \
+            PLASMA_enum, PlasmaLower,                                   \
+            PLASMA_enum, PlasmaNoTrans,                                 \
+            PLASMA_enum, PlasmaUnit,                                    \
+            PLASMA_Complex32_t, 1.0,                                    \
+            PLASMA_desc, (_A),                                          \
+            PLASMA_desc, (_X),                                          \
+            PLASMA_sequence*, sequence,                                 \
+            PLASMA_request*, request);                                  \
+                                                                        \
+        plasma_parallel_call_9(                                         \
+            plasma_pctrsm,                                              \
+            PLASMA_enum, PlasmaLeft,                                    \
+            PLASMA_enum, PlasmaUpper,                                   \
+            PLASMA_enum, PlasmaNoTrans,                                 \
+            PLASMA_enum, PlasmaNonUnit,                                 \
+            PLASMA_Complex32_t, 1.0,                                    \
+            PLASMA_desc, (_A),                                          \
+            PLASMA_desc, (_X),                                          \
+            PLASMA_sequence*, sequence,                                 \
+            PLASMA_request*, request);                                  \
+    }
+
 /***************************************************************************//**
  *
  * @ingroup PLASMA_Complex64_t
@@ -138,17 +222,15 @@
  *
  ******************************************************************************/
 int PLASMA_zcgesv(int N, int NRHS,
-                  PLASMA_Complex64_t *A, int LDA,
+                  PLASMA_Complex64_t *A, int LDA, int * IPIV,
                   PLASMA_Complex64_t *B, int LDB,
                   PLASMA_Complex64_t *X, int LDX, int *ITER)
 {
     int NB;
     int status;
-    int *IPIV;
     PLASMA_desc  descA;
     PLASMA_desc  descB;
     PLASMA_desc  descX;
-    PLASMA_desc *descL;
     plasma_context_t *plasma;
     PLASMA_sequence *sequence = NULL;
     PLASMA_request request = PLASMA_REQUEST_INITIALIZER;
@@ -209,11 +291,8 @@ int PLASMA_zcgesv(int N, int NRHS,
         descX.mat = X;
     }
 
-    /* Allocate Workspace */
-    PLASMA_Alloc_Workspace_zgesv_Tile(N, &descL, &IPIV);
-
     /* Call the native interface */
-    status = PLASMA_zcgesv_Tile_Async(&descA, descL, IPIV, &descB, &descX, ITER, sequence, &request);
+    status = PLASMA_zcgesv_Tile_Async(&descA, IPIV, &descB, &descX, ITER, sequence, &request);
 
     if (status == PLASMA_SUCCESS) {
         if ( PLASMA_TRANSLATION == PLASMA_OUTOFPLACE ) {
@@ -230,12 +309,9 @@ int PLASMA_zcgesv(int N, int NRHS,
         }
     }
 
-    /* Allocate Workspace */
-    PLASMA_Dealloc_Handle_Tile(&descL);
-
     status = sequence->status;
     plasma_sequence_destroy(plasma, sequence);
-    return PLASMA_INFO;
+    return status;
 }
 
 
@@ -268,10 +344,15 @@ int PLASMA_zcgesv(int N, int NRHS,
  * @param[out] IPIV
  *          On exit, the pivot indices that define the permutations (not equivalent to LAPACK).
  *
- * @param[in,out] B
+ * @param[in] B
  *          On entry, the N-by-NRHS matrix of right hand side matrix B.
+ *
+ * @param[out] X
  *          On exit, if return value = 0, the N-by-NRHS solution matrix X.
  *
+ * @param[out] ITER
+ *          The number of the current iteration in the iterative refinement process
+ *
  *******************************************************************************
  *
  * @return
@@ -287,7 +368,7 @@ int PLASMA_zcgesv(int N, int NRHS,
  * @sa PLASMA_zgesv_Tile
  *
  ******************************************************************************/
-int PLASMA_zcgesv_Tile(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
+int PLASMA_zcgesv_Tile(PLASMA_desc *A, int *IPIV,
                        PLASMA_desc *B, PLASMA_desc *X, int *ITER)
 {
     plasma_context_t *plasma;
@@ -301,7 +382,7 @@ int PLASMA_zcgesv_Tile(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
         return PLASMA_ERR_NOT_INITIALIZED;
     }
     plasma_sequence_create(plasma, &sequence);
-    status = PLASMA_zcgesv_Tile_Async(A, L, IPIV, B, X, ITER, sequence, &request);
+    status = PLASMA_zcgesv_Tile_Async(A, IPIV, B, X, ITER, sequence, &request);
     if (status != PLASMA_SUCCESS)
         return status;
     plasma_dynamic_sync();
@@ -337,16 +418,15 @@ int PLASMA_zcgesv_Tile(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
  * @sa PLASMA_zgesv_Tile_Async
  *
  ******************************************************************************/
-int PLASMA_zcgesv_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
+int PLASMA_zcgesv_Tile_Async(PLASMA_desc *A, int *IPIV,
                              PLASMA_desc *B, PLASMA_desc *X, int *ITER,
                              PLASMA_sequence *sequence, PLASMA_request *request)
 {
-    int N, NB, IB, Isize, Lsize;
+    int N, NB;
     PLASMA_desc descA = *A;
-    PLASMA_desc descL = *L;
     PLASMA_desc descB = *B;
     PLASMA_desc descX = *X;
-    PLASMA_desc descR, descSA, descSL, descSX;
+    PLASMA_desc descR, descSA, descSX;
     plasma_context_t *plasma;
     double *work;
 
@@ -363,15 +443,25 @@ int PLASMA_zcgesv_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
         plasma_fatal_error("PLASMA_zcgesv_Tile", "PLASMA not initialized");
         return PLASMA_ERR_NOT_INITIALIZED;
     }
+    if (sequence == NULL) {
+        plasma_fatal_error("PLASMA_zcgesv_Tile", "NULL sequence");
+        return PLASMA_ERR_UNALLOCATED;
+    }
+    if (request == NULL) {
+        plasma_fatal_error("PLASMA_zcgesv_Tile", "NULL request");
+        return PLASMA_ERR_UNALLOCATED;
+    }
+    /* Check sequence status */
+    if (sequence->status == PLASMA_SUCCESS)
+        request->status = PLASMA_SUCCESS;
+    else
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
+
     /* Check descriptors for correctness */
     if (plasma_desc_check(&descA) != PLASMA_SUCCESS) {
         plasma_error("PLASMA_zcgesv_Tile", "invalid first descriptor");
         return PLASMA_ERR_ILLEGAL_VALUE;
     }
-    if (plasma_desc_check(&descL) != PLASMA_SUCCESS) {
-        plasma_error("PLASMA_zcgesv_Tile", "invalid second descriptor");
-        return PLASMA_ERR_ILLEGAL_VALUE;
-    }
     if (plasma_desc_check(&descB) != PLASMA_SUCCESS) {
         plasma_error("PLASMA_zcgesv_Tile", "invalid third descriptor");
         return PLASMA_ERR_ILLEGAL_VALUE;
@@ -387,11 +477,8 @@ int PLASMA_zcgesv_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
     }
 
     /* Set N, NRHS, NT  */
-    N     = descA.lm;
+    N     = descA.m;
     NB    = descA.nb;
-    IB    = descL.mb;
-    Isize = descL.mt*descL.nt*descL.nb;
-    Lsize = descL.mt*descL.nt*descL.bsiz;
 
     work = (double *)plasma_shared_alloc(plasma, PLASMA_SIZE, PlasmaRealDouble);
     if (work == NULL) {
@@ -400,10 +487,14 @@ int PLASMA_zcgesv_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
         return PLASMA_ERR_OUT_OF_RESOURCES;
     }
 
-    plasma_zdesc_alloc( descR,  NB, NB, descB.m, descB.n, 0, 0, descB.m, descB.n, plasma_shared_free( plasma, work ); plasma_desc_mat_free(&descR) );
-    plasma_cdesc_alloc( descSA, NB, NB, descA.m, descA.n, 0, 0, descA.m, descA.n, plasma_shared_free( plasma, work ); plasma_desc_mat_free(&descR); plasma_desc_mat_free(&descSA) );
-    plasma_cdesc_alloc( descSL, IB, NB, descL.m, descL.n, 0, 0, descL.m, descL.n, plasma_shared_free( plasma, work ); plasma_desc_mat_free(&descR); plasma_desc_mat_free(&descSA); plasma_desc_mat_free(&descSL) );
-    plasma_cdesc_alloc( descSX, NB, NB, descX.m, descX.n, 0, 0, descX.m, descX.n, plasma_shared_free( plasma, work ); plasma_desc_mat_free(&descR); plasma_desc_mat_free(&descSA); plasma_desc_mat_free(&descSL); plasma_desc_mat_free(&descSX) );
+    plasma_zdesc_alloc( descR,  NB, NB, descB.m, descB.n, 0, 0, descB.m, descB.n, 
+                        plasma_shared_free( plasma, work ); plasma_desc_mat_free(&descR) );
+    plasma_cdesc_alloc( descSA, NB, NB, descA.m, descA.n, 0, 0, descA.m, descA.n, 
+                        plasma_shared_free( plasma, work ); plasma_desc_mat_free(&descR); 
+                        plasma_desc_mat_free(&descSA) );
+    plasma_cdesc_alloc( descSX, NB, NB, descX.m, descX.n, 0, 0, descX.m, descX.n, 
+                        plasma_shared_free( plasma, work ); plasma_desc_mat_free(&descR); 
+                        plasma_desc_mat_free(&descSA); plasma_desc_mat_free(&descSX) );
 
     /* Compute some constants */
     PLASMA_zlange(PlasmaInfNorm, descA, Anorm, work);
@@ -412,53 +503,39 @@ int PLASMA_zcgesv_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
     /* Convert B from double precision to single precision and store
        the result in SX. */
     PLASMA_zlag2c(descB, descSX);
+    if (sequence->status != PLASMA_SUCCESS)
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
 
     /* Convert A from double precision to single precision and store
        the result in SA. */
     PLASMA_zlag2c(descA, descSA);
+    if (sequence->status != PLASMA_SUCCESS)
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
 
     /* Clear IPIV and Lbdl */
-    plasma_memzero(IPIV,       Isize, PlasmaInteger);
-    plasma_memzero(descSL.mat, Lsize, PlasmaComplexFloat);
-
-    /* Set INFO to ZERO */
-    PLASMA_INFO = PLASMA_SUCCESS;
+    plasma_memzero(IPIV, N, PlasmaInteger);
 
     /* Compute the LU factorization of SA */
-    plasma_parallel_call_5(plasma_pcgetrf,
+    plasma_dynamic_call_3(
+        plasma_pcbarrier_tl2pnl,
+        PLASMA_desc, descSA,
+        PLASMA_sequence*, sequence,
+        PLASMA_request*,  request);
+
+    plasma_dynamic_call_4(plasma_pcgetrf_rectil,
         PLASMA_desc, descSA,
-        PLASMA_desc, descSL,
         int*, IPIV,
         PLASMA_sequence*, sequence,
         PLASMA_request*, request);
 
     /* Solve the system SA*SX = SB */
-    /* Forward substitution */
-    plasma_parallel_call_6(plasma_pctrsmpl,
-        PLASMA_desc, descSA,
-        PLASMA_desc, descSX,
-        PLASMA_desc, descSL,
-        int*, IPIV,
-        PLASMA_sequence*, sequence,
-        PLASMA_request*, request);
-
-    /* Backward substitution */
-    plasma_parallel_call_9(plasma_pctrsm,
-        PLASMA_enum, PlasmaLeft,
-        PLASMA_enum, PlasmaUpper,
-        PLASMA_enum, PlasmaNoTrans,
-        PLASMA_enum, PlasmaNonUnit,
-        PLASMA_Complex32_t, 1.0,
-        PLASMA_desc, descSA,
-        PLASMA_desc, descSX,
-        PLASMA_sequence*, sequence,
-        PLASMA_request*, request);
+    PLASMA_cgetrs(descSA, IPIV, descSX);
 
     /* Convert SX back to double precision */
     PLASMA_clag2z(descSX, descX);
 
     /* Compute R = B - AX. */
-    PLASMA_zlacpy(descB,descR);
+    PLASMA_zlacpy(descB, descR);
     plasma_parallel_call_9(plasma_pzgemm,
         PLASMA_enum, PlasmaNoTrans,
         PLASMA_enum, PlasmaNoTrans,
@@ -472,22 +549,21 @@ int PLASMA_zcgesv_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
 
     /* Check whether the NRHS normwise backward error satisfies the
        stopping criterion. If yes return. Note that ITER=0 (already set). */
-    PLASMA_zlange(PlasmaInfNorm, descX, Xnorm, work);
-    PLASMA_zlange(PlasmaInfNorm, descR, Rnorm, work);
+    PLASMA_zlange(PlasmaMaxNorm, descX, Xnorm, work);
+    PLASMA_zlange(PlasmaMaxNorm, descR, Rnorm, work);
 
     /* Wait the end of Anorm, Xnorm and Bnorm computations */
     plasma_dynamic_sync();
 
-    cte = Anorm*eps*((double) N)*bwdmax;
+    cte = Anorm*eps*sqrt((double) N)*bwdmax;
     if (Rnorm < Xnorm * cte){
         /* The NRHS normwise backward errors satisfy the
            stopping criterion. We are good to exit. */
         plasma_desc_mat_free(&descSA);
-        plasma_desc_mat_free(&descSL);
         plasma_desc_mat_free(&descSX);
         plasma_desc_mat_free(&descR);
         plasma_shared_free(plasma, work);
-        return PLASMA_INFO;
+        return PLASMA_SUCCESS;
     }
 
     /* Iterative refinement */
@@ -497,27 +573,8 @@ int PLASMA_zcgesv_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
            and store the result in SX. */
         PLASMA_zlag2c(descR, descSX);
 
-        /* Solve the system SA*SX = SR */
-        /* Forward substitution */
-        plasma_parallel_call_6(plasma_pctrsmpl,
-            PLASMA_desc, descSA,
-            PLASMA_desc, descSX,
-            PLASMA_desc, descSL,
-            int*, IPIV,
-            PLASMA_sequence*, sequence,
-            PLASMA_request*, request);
-
-        /* Backward substitution */
-        plasma_parallel_call_9(plasma_pctrsm,
-            PLASMA_enum, PlasmaLeft,
-            PLASMA_enum, PlasmaUpper,
-            PLASMA_enum, PlasmaNoTrans,
-            PLASMA_enum, PlasmaNonUnit,
-            PLASMA_Complex32_t, 1.0,
-            PLASMA_desc, descSA,
-            PLASMA_desc, descSX,
-            PLASMA_sequence*, sequence,
-            PLASMA_request*, request);
+        /* Solve the system SA*SX = SB */
+        PLASMA_cgetrs(descSA, IPIV, descSX);
 
         /* Convert SX back to double precision and update the current
            iterate. */
@@ -551,11 +608,10 @@ int PLASMA_zcgesv_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
             *ITER = iiter;
 
             plasma_desc_mat_free(&descSA);
-            plasma_desc_mat_free(&descSL);
             plasma_desc_mat_free(&descSX);
             plasma_desc_mat_free(&descR);
             plasma_shared_free(plasma, work);
-            return PLASMA_INFO;
+            return PLASMA_SUCCESS;
         }
     }
 
@@ -565,7 +621,6 @@ int PLASMA_zcgesv_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
     *ITER = -itermax - 1;
 
     plasma_desc_mat_free(&descSA);
-    plasma_desc_mat_free(&descSL);
     plasma_desc_mat_free(&descSX);
     plasma_desc_mat_free(&descR);
     plasma_shared_free(plasma, work);
@@ -574,39 +629,17 @@ int PLASMA_zcgesv_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
        satisfactory solution, so we resort to double precision. */
 
     /* Clear IPIV and Lbdl */
-    plasma_memzero(IPIV,      Isize, PlasmaInteger);
-    plasma_memzero(descL.mat, Lsize, PlasmaComplexDouble);
+    plasma_memzero(IPIV, N, PlasmaInteger);
 
-    /* Set INFO to ZERO */
-    PLASMA_INFO = PLASMA_SUCCESS;
-
-    plasma_parallel_call_5(plasma_pzgetrf,
+    plasma_dynamic_call_4(plasma_pzgetrf_rectil,
         PLASMA_desc, descA,
-        PLASMA_desc, descL,
         int*, IPIV,
         PLASMA_sequence*, sequence,
         PLASMA_request*, request);
 
-    PLASMA_zlacpy(descB,descX);
+    PLASMA_zlacpy(descB, descX);
 
-    plasma_parallel_call_6(plasma_pztrsmpl,
-        PLASMA_desc, descA,
-        PLASMA_desc, descX,
-        PLASMA_desc, descL,
-        int*, IPIV,
-        PLASMA_sequence*, sequence,
-        PLASMA_request*, request);
-
-    plasma_parallel_call_9(plasma_pztrsm,
-        PLASMA_enum, PlasmaLeft,
-        PLASMA_enum, PlasmaUpper,
-        PLASMA_enum, PlasmaNoTrans,
-        PLASMA_enum, PlasmaNonUnit,
-        PLASMA_Complex64_t, 1.0,
-        PLASMA_desc, descA,
-        PLASMA_desc, descX,
-        PLASMA_sequence*, sequence,
-        PLASMA_request*, request);
-
-    return PLASMA_INFO;
+    PLASMA_zgetrs(descA, IPIV, descX);
+    
+    return PLASMA_SUCCESS;
 }
