@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Emmanuel Agullo
  * @date 2010-11-15
  * @precisions mixed zc -> ds
@@ -112,6 +112,11 @@
  *
  *******************************************************************************
  *
+ * @param[in] uplo
+ *          Specifies whether the matrix A is upper triangular or lower triangular:
+ *          = PlasmaUpper: Upper triangle of A is stored;
+ *          = PlasmaLower: Lower triangle of A is stored.
+ *
  * @param[in] N
  *          The number of linear equations, i.e., the order of the matrix A. N >= 0.
  *
@@ -256,8 +261,9 @@ int PLASMA_zcposv(PLASMA_enum uplo, int N, int NRHS,
         }
     }
 
+    status = sequence->status;
     plasma_sequence_destroy(plasma, sequence);
-    return PLASMA_INFO;
+    return status;
 }
 
 
@@ -290,10 +296,15 @@ int PLASMA_zcposv(PLASMA_enum uplo, int N, int NRHS,
  *          - If the iterative refinement converged, A is not modified;
  *          - otherwise, it falled backed to double precision solution,
  *
- * @param[in,out] B
+ * @param[in] B
  *          On entry, the N-by-NRHS matrix of right hand side matrix B.
+ *
+ * @param[out] X
  *          On exit, if return value = 0, the N-by-NRHS solution matrix X.
  *
+ * @param[out] ITER
+ *          The number of the current iteration in the iterative refinement process
+ *
  *******************************************************************************
  *
  * @return
@@ -385,6 +396,20 @@ int PLASMA_zcposv_Tile_Async(PLASMA_enum uplo, PLASMA_desc *A, PLASMA_desc *B,
         plasma_fatal_error("PLASMA_zcposv_Tile", "PLASMA not initialized");
         return PLASMA_ERR_NOT_INITIALIZED;
     }
+    if (sequence == NULL) {
+        plasma_fatal_error("PLASMA_zcposv_Tile", "NULL sequence");
+        return PLASMA_ERR_UNALLOCATED;
+    }
+    if (request == NULL) {
+        plasma_fatal_error("PLASMA_zcposv_Tile", "NULL request");
+        return PLASMA_ERR_UNALLOCATED;
+    }
+    /* Check sequence status */
+    if (sequence->status == PLASMA_SUCCESS)
+        request->status = PLASMA_SUCCESS;
+    else
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
+
     /* Check descriptors for correctness */
     if (plasma_desc_check(&descA) != PLASMA_SUCCESS) {
         plasma_error("PLASMA_zcposv_Tile", "invalid first descriptor");
@@ -438,13 +463,14 @@ int PLASMA_zcposv_Tile_Async(PLASMA_enum uplo, PLASMA_desc *A, PLASMA_desc *B,
     /* Convert B from double precision to single precision and store
        the result in SX. */
     PLASMA_zlag2c(descB, descSX);
+    if (sequence->status != PLASMA_SUCCESS)
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
 
     /* Convert A from double precision to single precision and store
        the result in SA. */
     PLASMA_zlag2c(descA, descSA);
-
-    /* Set INFO to ZERO */
-    PLASMA_INFO = PLASMA_SUCCESS; // EA2ALL: not there in zposv; which should we change ?
+    if (sequence->status != PLASMA_SUCCESS)
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
 
     /* Compute the Cholesky factorization of SA */
     plasma_parallel_call_4(plasma_pcpotrf,
@@ -510,7 +536,7 @@ int PLASMA_zcposv_Tile_Async(PLASMA_enum uplo, PLASMA_desc *A, PLASMA_desc *B,
         plasma_desc_mat_free(&descSX);
         plasma_desc_mat_free(&descR);
         plasma_shared_free(plasma, work);
-        return PLASMA_INFO;
+        return PLASMA_SUCCESS;
     }
 
     /* Iterative refinement */
@@ -580,7 +606,7 @@ int PLASMA_zcposv_Tile_Async(PLASMA_enum uplo, PLASMA_desc *A, PLASMA_desc *B,
             plasma_desc_mat_free(&descSX);
             plasma_desc_mat_free(&descR);
             plasma_shared_free(plasma, work);
-            return PLASMA_INFO;
+            return PLASMA_SUCCESS;
         }
     }
 
@@ -597,9 +623,6 @@ int PLASMA_zcposv_Tile_Async(PLASMA_enum uplo, PLASMA_desc *A, PLASMA_desc *B,
     /* Single-precision iterative refinement failed to converge to a
        satisfactory solution, so we resort to double precision. */
 
-    /* Set INFO to ZERO */
-    PLASMA_INFO = PLASMA_SUCCESS; // EA2ALL: Not there is zposv; which one should we change.
-
     plasma_parallel_call_4(plasma_pzpotrf,
         PLASMA_enum, uplo,
         PLASMA_desc, descA,
@@ -630,5 +653,5 @@ int PLASMA_zcposv_Tile_Async(PLASMA_enum uplo, PLASMA_desc *A, PLASMA_desc *B,
         PLASMA_sequence*, sequence,
         PLASMA_request*, request);
 
-    return PLASMA_INFO;
+    return PLASMA_SUCCESS;
 }
