@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Emmanuel Agullo
  * @date 2010-11-15
  * @precisions mixed zc -> ds
@@ -114,9 +114,6 @@
  *          = PlasmaConjTrans: the linear system involves A**H.
  *          Currently only PlasmaNoTrans is supported.
  *
- * @param[in] M
- *          The number of rows of the matrix A. M >= 0.
- *
  * @param[in] N
  *          The number of columns of the matrix A. N >= 0.
  *
@@ -302,12 +299,18 @@ int PLASMA_zcungesv(PLASMA_enum trans, int N, int NRHS,
  *
  * @param[in,out] B
  *          On entry, the M-by-NRHS matrix B of right hand side vectors, stored columnwise;
- *          On exit, if return value = 0, B is overwritten by the solution vectors, stored
- *          columnwise:
- *          if M >= N, rows 1 to N of B contain the least squares solution vectors; the residual
+ * @param[in] B
+ *          The N-by-NRHS matrix of right hand side matrix B.
+ *
+ * @param[out] X
+ *          If return value = 0, X is the solution vectors, stored columnwise:
+ *          if M >= N, rows 1 to N of X contain the least squares solution vectors; the residual
  *          sum of squares for the solution in each column is given by the sum of squares of the
  *          modulus of elements N+1 to M in that column;
- *          if M < N, rows 1 to N of B contain the minimum norm solution vectors;
+ *          if M < N, rows 1 to N of X contain the minimum norm solution vectors;
+ *
+ * @param[out] ITER
+ *          The number of the current iteration in the iterative refinement process
  *
  *******************************************************************************
  *
@@ -398,6 +401,19 @@ int PLASMA_zcungesv_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, PLASMA_desc *T
         plasma_fatal_error("PLASMA_zcungesv_Tile", "PLASMA not initialized");
         return PLASMA_ERR_NOT_INITIALIZED;
     }
+    if (sequence == NULL) {
+        plasma_fatal_error("PLASMA_zcungesv_Tile", "NULL sequence");
+        return PLASMA_ERR_UNALLOCATED;
+    }
+    if (request == NULL) {
+        plasma_fatal_error("PLASMA_zcungesv_Tile", "NULL request");
+        return PLASMA_ERR_UNALLOCATED;
+    }
+    /* Check sequence status */
+    if (sequence->status == PLASMA_SUCCESS)
+        request->status = PLASMA_SUCCESS;
+    else
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
     /* Check descriptors for correctness */
     if (plasma_desc_check(&descA) != PLASMA_SUCCESS) {
         plasma_error("PLASMA_zcungesv_Tile", "invalid first descriptor");
@@ -450,13 +466,14 @@ int PLASMA_zcungesv_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, PLASMA_desc *T
     /* Convert B from double precision to single precision and store
        the result in SX. */
     PLASMA_zlag2c(descB, descSX);
+    if (sequence->status != PLASMA_SUCCESS)
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
 
     /* Convert A from double precision to single precision and store
        the result in SA. */
     PLASMA_zlag2c(descA, descSA);
-
-    /* Set INFO to ZERO */
-    PLASMA_INFO = PLASMA_SUCCESS;
+    if (sequence->status != PLASMA_SUCCESS)
+        return plasma_request_fail(sequence, request, PLASMA_ERR_SEQUENCE_FLUSHED);
 
     /* Compute the QR factorization of SA */
     plasma_parallel_call_4(plasma_pcgeqrf,
@@ -466,7 +483,9 @@ int PLASMA_zcungesv_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, PLASMA_desc *T
         PLASMA_request*, request);
 
     /* Compute the solve in simple */
-    plasma_parallel_call_5(plasma_pcunmqr,
+    plasma_parallel_call_7(plasma_pcunmqr,
+        PLASMA_enum, PlasmaLeft,
+        PLASMA_enum, PlasmaConjTrans,
         PLASMA_desc, descSA,
         PLASMA_desc, descSX,
         PLASMA_desc, descST,
@@ -518,7 +537,7 @@ int PLASMA_zcungesv_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, PLASMA_desc *T
         plasma_desc_mat_free(&descSX);
         plasma_desc_mat_free(&descR);
         plasma_shared_free(plasma, work);
-        return PLASMA_INFO;
+        return PLASMA_SUCCESS;
     }
 
     /* Iterative refinement */
@@ -528,7 +547,9 @@ int PLASMA_zcungesv_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, PLASMA_desc *T
            and store the result in SX. */
         PLASMA_zlag2c(descR, descSX);
 
-        plasma_parallel_call_5(plasma_pcunmqr,
+        plasma_parallel_call_7(plasma_pcunmqr,
+            PLASMA_enum, PlasmaLeft,
+            PLASMA_enum, PlasmaConjTrans,
             PLASMA_desc, descSA,
             PLASMA_desc, descSX,
             PLASMA_desc, descST,
@@ -582,7 +603,7 @@ int PLASMA_zcungesv_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, PLASMA_desc *T
             plasma_desc_mat_free(&descSX);
             plasma_desc_mat_free(&descR);
             plasma_shared_free(plasma, work);
-            return PLASMA_INFO;
+            return PLASMA_SUCCESS;
         }
     }
 
@@ -607,7 +628,9 @@ int PLASMA_zcungesv_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, PLASMA_desc *T
         PLASMA_sequence*, sequence,
         PLASMA_request*, request);
 
-    plasma_parallel_call_5(plasma_pzunmqr,
+    plasma_parallel_call_7(plasma_pzunmqr,
+        PLASMA_enum, PlasmaLeft,
+        PLASMA_enum, PlasmaConjTrans,
         PLASMA_desc, descA,
         PLASMA_desc, descX,
         PLASMA_desc, descT,
