@@ -10,7 +10,7 @@
  *  based on the GKK algorithm by Gustavson, Karlsson, Kagstrom 
  *  and its fortran implementation.
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Mathieu Faverge
  * @date 2010-11-15
  *
@@ -54,13 +54,16 @@
  *
  *******************************************************************************
  *
+ * @param[in] plasma
+ *          Plasma context to which this call belong to.
+ *
  * @param[in] m
  *         Number of rows of matrix A
  *
  * @param[in] n
  *         Number of columns of matrix A
  *
- * @param[in/out] A
+ * @param[in,out] A
  *         Matrix of size m*n.
  *
  * @param[in] mb
@@ -69,6 +72,13 @@
  * @param[in] nb
  *         Number of columns of each block
  *
+ * @param[in] sequence
+ *          Identifies the sequence of function calls that this call belongs to
+ *          (for completion checks and exception handling purposes).
+ *
+ * @param[out] request
+ *          Identifies this function call (for exception handling purposes).
+ *
  ******************************************************************************/
 
 
@@ -422,6 +432,8 @@ int ipt_ztile2panel( plasma_context_t *plasma, int m, int n, PLASMA_Complex64_t
     int N_ = n / nb;
     int bsiz = mb*nb;
     int psiz = m*nb;
+    Quark_Task_Flags task_flags = Quark_Task_Flags_Initializer;
+    QUARK_Task_Flag_Set(&task_flags, TASK_SEQUENCE, (intptr_t)sequence->quark_sequence);
 
     plasma_dynamic_spawn();
     for(j=0; j<N_; j++) {
@@ -433,7 +445,7 @@ int ipt_ztile2panel( plasma_context_t *plasma, int m, int n, PLASMA_Complex64_t
             char str[30];
             sprintf(str, "Foo2 C2RI %d", i*m*nb);
 #endif
-            QUARK_Insert_Task(plasma->quark, CORE_foo2_quark, 0x00,
+            QUARK_Insert_Task(plasma->quark, CORE_foo2_quark, &task_flags,
                               sizeof(PLASMA_Complex64_t)*psiz,  Al,           INOUT | GATHERV,
                               sizeof(PLASMA_Complex64_t)*bsiz, &(Al[i*bsiz]), INOUT,
 #ifdef TRACE_IPT
@@ -459,6 +471,8 @@ int ipt_zpanel2tile( plasma_context_t *plasma, int m, int n, PLASMA_Complex64_t
     int N_ = n / nb;
     int bsiz = mb*nb;
     int psiz = m*nb;
+    Quark_Task_Flags task_flags = Quark_Task_Flags_Initializer;
+    QUARK_Task_Flag_Set(&task_flags, TASK_SEQUENCE, (intptr_t)sequence->quark_sequence);
 
     plasma_dynamic_spawn();
     for(j=0; j<N_; j++) {
@@ -470,7 +484,7 @@ int ipt_zpanel2tile( plasma_context_t *plasma, int m, int n, PLASMA_Complex64_t
             char str[30];
             sprintf(str, "Foo2 C2RI %d", i*m*nb);
 #endif
-            QUARK_Insert_Task(plasma->quark, CORE_foo2_quark, 0x00,
+            QUARK_Insert_Task(plasma->quark, CORE_foo2_quark, &task_flags,
                               sizeof(PLASMA_Complex64_t)*psiz,  Al,           INPUT,
                               sizeof(PLASMA_Complex64_t)*bsiz, &(Al[i*bsiz]), INOUT,
 #ifdef TRACE_IPT
@@ -492,6 +506,8 @@ int ipt_zpanel2all(plasma_context_t *plasma, int m, int n, PLASMA_Complex64_t *A
 
     int i;
     int N_ = n / nb;
+    Quark_Task_Flags task_flags = Quark_Task_Flags_Initializer;
+    QUARK_Task_Flag_Set(&task_flags, TASK_SEQUENCE, (intptr_t)sequence->quark_sequence);
 
     if ( N_ > 1 ) {
         plasma_dynamic_spawn();
@@ -500,7 +516,7 @@ int ipt_zpanel2all(plasma_context_t *plasma, int m, int n, PLASMA_Complex64_t *A
             char str[30];
             sprintf(str, "Foo2 C2RI %d", i*m*nb);
 #endif
-            QUARK_Insert_Task(plasma->quark, CORE_foo2_quark, 0x00,
+            QUARK_Insert_Task(plasma->quark, CORE_foo2_quark, &task_flags,
                               sizeof(PLASMA_Complex64_t)*m*n,  A,            INOUT | GATHERV,
                               sizeof(PLASMA_Complex64_t)*m*nb, &(A[i*m*nb]), INPUT,
 #ifdef TRACE_IPT
@@ -522,6 +538,8 @@ int ipt_zall2panel(plasma_context_t *plasma, int m, int n, PLASMA_Complex64_t *A
 
     int i;
     int N_ = n / nb;
+    Quark_Task_Flags task_flags = Quark_Task_Flags_Initializer;
+    QUARK_Task_Flag_Set(&task_flags, TASK_SEQUENCE, (intptr_t)sequence->quark_sequence);
 
     if ( N_ > 1 ) {
         plasma_dynamic_spawn();
@@ -530,7 +548,7 @@ int ipt_zall2panel(plasma_context_t *plasma, int m, int n, PLASMA_Complex64_t *A
             char str[30];
             sprintf(str, "Foo2 C2RI %d", i*m*nb);
 #endif
-            QUARK_Insert_Task(plasma->quark, CORE_foo2_quark, 0x00,
+            QUARK_Insert_Task(plasma->quark, CORE_foo2_quark, &task_flags,
                               sizeof(PLASMA_Complex64_t)*m*n,  A,            INPUT,
                               sizeof(PLASMA_Complex64_t)*m*nb, &(A[i*m*nb]), INOUT,
 #ifdef TRACE_IPT
