@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Jakub Kurzak
  * @date 2010-11-15
  * @precisions normal z -> s d c
@@ -379,7 +379,9 @@ int PLASMA_zgels_Tile_Async(PLASMA_enum trans, PLASMA_desc *A,
                 PLASMA_sequence*, sequence,
                 PLASMA_request*, request);
 
-            plasma_parallel_call_5(plasma_pzunmqr,
+            plasma_parallel_call_7(plasma_pzunmqr,
+                PLASMA_enum, PlasmaLeft,
+                PLASMA_enum, PlasmaConjTrans,
                 PLASMA_desc, descA,
                 PLASMA_desc, descB,
                 PLASMA_desc, descT,
@@ -394,7 +396,9 @@ int PLASMA_zgels_Tile_Async(PLASMA_enum trans, PLASMA_desc *A,
                 PLASMA_sequence*, sequence,
                 PLASMA_request*, request);
 
-            plasma_dynamic_call_6(plasma_pzunmqrrh,
+            plasma_dynamic_call_8(plasma_pzunmqrrh,
+                PLASMA_enum, PlasmaLeft,
+                PLASMA_enum, PlasmaConjTrans,
                 PLASMA_desc, descA,
                 PLASMA_desc, descB,
                 PLASMA_desc, descT,
@@ -446,7 +450,9 @@ int PLASMA_zgels_Tile_Async(PLASMA_enum trans, PLASMA_desc *A,
             PLASMA_request*, request);
 
         if (plasma->householder == PLASMA_FLAT_HOUSEHOLDER) {
-            plasma_parallel_call_5(plasma_pzunmlq,
+            plasma_parallel_call_7(plasma_pzunmlq,
+                PLASMA_enum, PlasmaLeft,
+                PLASMA_enum, PlasmaConjTrans,
                 PLASMA_desc, descA,
                 PLASMA_desc, descB,
                 PLASMA_desc, descT,
@@ -454,7 +460,9 @@ int PLASMA_zgels_Tile_Async(PLASMA_enum trans, PLASMA_desc *A,
                 PLASMA_request*, request);
         }
         else {
-            plasma_dynamic_call_6(plasma_pzunmlqrh,
+            plasma_dynamic_call_8(plasma_pzunmlqrh,
+                PLASMA_enum, PlasmaLeft,
+                PLASMA_enum, PlasmaConjTrans,
                 PLASMA_desc, descA,
                 PLASMA_desc, descB,
                 PLASMA_desc, descT,
