@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Jakub Kurzak
  * @date 2010-11-15
  * @precisions normal z -> s d c
@@ -171,7 +171,7 @@ int PLASMA_zgeqrs(int M, int N, int NRHS,
  * @ingroup PLASMA_Complex64_t_Tile
  *
  *  PLASMA_zgeqrs_Tile - Computes a minimum-norm solution using the tile QR factorization.
- *  Tile equivalent of PLASMA_zgetrf().
+ *  Tile equivalent of PLASMA_zgeqrf().
  *  Operates on matrices stored by tiles.
  *  All matrices are passed through descriptors.
  *  All dimensions are taken from the descriptors.
@@ -304,7 +304,9 @@ int PLASMA_zgeqrs_Tile_Async(PLASMA_desc *A, PLASMA_desc *T, PLASMA_desc *B,
     }
 */
     if (plasma->householder == PLASMA_FLAT_HOUSEHOLDER) {
-        plasma_parallel_call_5(plasma_pzunmqr,
+        plasma_parallel_call_7(plasma_pzunmqr,
+            PLASMA_enum, PlasmaLeft,
+            PLASMA_enum, PlasmaConjTrans,
             PLASMA_desc, descA,
             PLASMA_desc, descB,
             PLASMA_desc, descT,
@@ -312,7 +314,9 @@ int PLASMA_zgeqrs_Tile_Async(PLASMA_desc *A, PLASMA_desc *T, PLASMA_desc *B,
             PLASMA_request*, request);
     }
     else {
-        plasma_dynamic_call_6(plasma_pzunmqrrh,
+        plasma_dynamic_call_8(plasma_pzunmqrrh,
+            PLASMA_enum, PlasmaLeft,
+            PLASMA_enum, PlasmaConjTrans,
             PLASMA_desc, descA,
             PLASMA_desc, descB,
             PLASMA_desc, descT,
