@@ -6,9 +6,11 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
- * @author Jakub Kurzak
- * @date 2010-11-15
+ * @version 2.4.0
+ * @author Hatem Ltaief
+ * @author Mathieu Faverge
+ * @date 2009-11-15
+ *
  * @precisions normal z -> s d c
  *
  **/
@@ -36,12 +38,8 @@
  * @param[in] LDA
  *          The leading dimension of the array A. LDA >= max(1,M).
  *
- * @param[out] L
- *          On exit, auxiliary factorization data, related to the tile L factor,
- *          required by PLASMA_zgetrs to solve the system of equations.
- *
  * @param[out] IPIV
- *          The pivot indices that define the permutations (not equivalent to LAPACK).
+ *          The pivot indices that define the permutations.
  *
  *******************************************************************************
  *
@@ -59,19 +57,18 @@
  * @sa PLASMA_cgetrf
  * @sa PLASMA_dgetrf
  * @sa PLASMA_sgetrf
- * @sa PLASMA_zgetrs
  *
  ******************************************************************************/
 int PLASMA_zgetrf(int M, int N,
                   PLASMA_Complex64_t *A, int LDA,
-                  PLASMA_Complex64_t *L, int *IPIV)
+                  int *IPIV)
 {
-    int NB, IB, IBNB, MT, NT;
+    int NB, NBNB;
     int status;
+    PLASMA_desc descA ;
     plasma_context_t *plasma;
     PLASMA_sequence *sequence = NULL;
     PLASMA_request request = PLASMA_REQUEST_INITIALIZER;
-    PLASMA_desc descA, descL;
 
     plasma = plasma_context_self();
     if (plasma == NULL) {
@@ -104,39 +101,44 @@ int PLASMA_zgetrf(int M, int N,
 
     /* Set NT & NTRHS */
     NB   = PLASMA_NB;
-    IB   = PLASMA_IB;
-    IBNB = IB*NB;
-    MT   = (M%NB==0) ? (M/NB) : (M/NB+1);
-    NT   = (N%NB==0) ? (N/NB) : (N/NB+1);
+    NBNB = NB*NB;
 
     plasma_sequence_create(plasma, &sequence);
 
-    descL = plasma_desc_init(
+    descA = plasma_desc_init(
         PlasmaComplexDouble,
-        IB, NB, IBNB,
-        MT*IB, NT*NB, 0, 0, MT*IB, NT*NB);
-    descL.mat = L;
+        NB, NB, NBNB,
+        LDA, N, 0, 0, M, N);
+    descA.mat = A;
 
-    if ( PLASMA_TRANSLATION == PLASMA_OUTOFPLACE ) {
-        plasma_zooplap2tile( descA, A, NB, NB, LDA, N, 0, 0, M, N, plasma_desc_mat_free(&(descA)) );
-    } else {
-        plasma_ziplap2tile( descA, A, NB, NB, LDA, N, 0, 0, M, N);
-    }
+    memset(IPIV, 0, M*sizeof(int));
 
     /* Call the tile interface */
-    PLASMA_zgetrf_Tile_Async(&descA, &descL, IPIV, sequence, &request);
+    plasma_dynamic_call_4(plasma_pzgetrf_reclap,
+        PLASMA_desc, descA,
+        int*, IPIV,
+        PLASMA_sequence*, sequence,
+        PLASMA_request*, &request);
 
-    if ( PLASMA_TRANSLATION == PLASMA_OUTOFPLACE ) {
-        plasma_zooptile2lap( descA, A, NB, NB, LDA, N );
-        plasma_dynamic_sync();
-        plasma_desc_mat_free(&descA);
-    } else {
-        plasma_ziptile2lap( descA, A, NB, NB, LDA, N );
-        plasma_dynamic_sync();
+    plasma_dynamic_sync();
+
+    /*
+     * Generate the correct IPIV (Has to be move in a task)
+     */
+    { 
+        int i, inc, tmp, j;
+        for(i=1; i<descA.mt; i++) {
+            inc = i*descA.mb;
+            tmp = i == descA.mt-1 ? descA.m-i*descA.mb : descA.mb;
+            
+            for (j=0; j<tmp; j++)
+                IPIV[inc+j] = IPIV[inc+j] + inc;
+        }
     }
 
     status = sequence->status;
     plasma_sequence_destroy(plasma, sequence);
+
     return status;
 }
 
@@ -181,7 +183,7 @@ int PLASMA_zgetrf(int M, int N,
  * @sa PLASMA_zgetrs_Tile
  *
  ******************************************************************************/
-int PLASMA_zgetrf_Tile(PLASMA_desc *A, PLASMA_desc *L, int *IPIV)
+int PLASMA_zgetrf_Tile(PLASMA_desc *A, int *IPIV)
 {
     plasma_context_t *plasma;
     PLASMA_sequence *sequence = NULL;
@@ -194,7 +196,7 @@ int PLASMA_zgetrf_Tile(PLASMA_desc *A, PLASMA_desc *L, int *IPIV)
         return PLASMA_ERR_NOT_INITIALIZED;
     }
     plasma_sequence_create(plasma, &sequence);
-    PLASMA_zgetrf_Tile_Async(A, L, IPIV, sequence, &request);
+    PLASMA_zgetrf_Tile_Async(A, IPIV, sequence, &request);
     plasma_dynamic_sync();
     status = sequence->status;
     plasma_sequence_destroy(plasma, sequence);
@@ -229,11 +231,10 @@ int PLASMA_zgetrf_Tile(PLASMA_desc *A, PLASMA_desc *L, int *IPIV)
  * @sa PLASMA_zgetrs_Tile_Async
  *
  ******************************************************************************/
-int PLASMA_zgetrf_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
+int PLASMA_zgetrf_Tile_Async(PLASMA_desc *A, int *IPIV,
                              PLASMA_sequence *sequence, PLASMA_request *request)
 {
     PLASMA_desc descA = *A;
-    PLASMA_desc descL = *L;
     plasma_context_t *plasma;
 
     plasma = plasma_context_self();
@@ -260,10 +261,6 @@ int PLASMA_zgetrf_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
         plasma_error("PLASMA_zgetrf_Tile", "invalid first descriptor");
         return plasma_request_fail(sequence, request, PLASMA_ERR_ILLEGAL_VALUE);
     }
-    if (plasma_desc_check(&descL) != PLASMA_SUCCESS) {
-        plasma_error("PLASMA_zgetrf_Tile", "invalid second descriptor");
-        return plasma_request_fail(sequence, request, PLASMA_ERR_ILLEGAL_VALUE);
-    }
     /* Check input arguments */
     if (descA.nb != descA.mb) {
         plasma_error("PLASMA_zgetrf_Tile", "only square tiles supported");
@@ -274,16 +271,24 @@ int PLASMA_zgetrf_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV,
     if (min(M, N) == 0)
         return PLASMA_SUCCESS;
 */
-    /* Clear IPIV and Lbdl */
-    plasma_memzero(IPIV,      descA.mt*descA.nt*descA.nb,          PlasmaInteger);
-    plasma_memzero(descL.mat, descL.mt*descL.nt*descL.mb*descL.nb, PlasmaComplexDouble);
 
-    plasma_parallel_call_5(plasma_pzgetrf,
+    plasma_dynamic_call_3(
+        plasma_pzbarrier_tl2pnl,
+        PLASMA_desc, descA,
+        PLASMA_sequence*, sequence,
+        PLASMA_request*,  request);
+    
+    plasma_dynamic_call_4(plasma_pzgetrf_rectil,
         PLASMA_desc, descA,
-        PLASMA_desc, descL,
         int*, IPIV,
         PLASMA_sequence*, sequence,
         PLASMA_request*, request);
 
+    plasma_dynamic_call_3(
+        plasma_pzbarrier_tl2pnl,
+        PLASMA_desc, descA,
+        PLASMA_sequence*, sequence,
+        PLASMA_request*,  request);
+    
     return PLASMA_SUCCESS;
 }
