@@ -6,8 +6,9 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Jakub Kurzak
+ * @author Mathieu Faverge
  * @date 2010-11-15
  * @precisions normal z -> s d c
  *
@@ -28,7 +29,6 @@
  *          = PlasmaNoTrans:   A * X = B     (No transpose)
  *          = PlasmaTrans:     A**T * X = B  (Transpose)
  *          = PlasmaConjTrans: A**H * X = B  (Conjugate transpose)
- *          Currently only PlasmaNoTrans is supported.
  *
  * @param[in] N
  *          The order of the matrix A.  N >= 0.
@@ -43,11 +43,8 @@
  * @param[in] LDA
  *          The leading dimension of the array A. LDA >= max(1,N).
  *
- * @param[in] L
- *          Auxiliary factorization data, related to the tile L factor, computed by PLASMA_zgetrf.
- *
  * @param[in] IPIV
- *          The pivot indices from PLASMA_zgetrf (not equivalent to LAPACK).
+ *          The pivot indices from PLASMA_zgetrf.
  *
  * @param[in,out] B
  *          On entry, the N-by-NRHS matrix of right hand side matrix B.
@@ -74,7 +71,7 @@
  ******************************************************************************/
 int PLASMA_zgetrs(PLASMA_enum trans, int N, int NRHS,
                   PLASMA_Complex64_t *A, int LDA,
-                  PLASMA_Complex64_t *L, int *IPIV,
+                  int *IPIV,
                   PLASMA_Complex64_t *B, int LDB)
 {
     int NB, IB, IBNB, NT;
@@ -82,7 +79,7 @@ int PLASMA_zgetrs(PLASMA_enum trans, int N, int NRHS,
     plasma_context_t *plasma;
     PLASMA_sequence *sequence = NULL;
     PLASMA_request request = PLASMA_REQUEST_INITIALIZER;
-    PLASMA_desc descA, descB, descL;
+    PLASMA_desc descA, descB;
 
     plasma = plasma_context_self();
     if (plasma == NULL) {
@@ -90,9 +87,11 @@ int PLASMA_zgetrs(PLASMA_enum trans, int N, int NRHS,
         return PLASMA_ERR_NOT_INITIALIZED;
     }
     /* Check input arguments */
-    if (trans != PlasmaNoTrans) {
-        plasma_error("PLASMA_zgetrs", "only PlasmaNoTrans supported");
-        return PLASMA_ERR_NOT_SUPPORTED;
+    if ( (trans != PlasmaNoTrans) && 
+         (trans != PlasmaTrans)   &&
+         (trans != PlasmaConjTrans)) {
+        plasma_error("PLASMA_zgetrs", "illegal value of trans");
+        return -1;
     }
     if (N < 0) {
         plasma_error("PLASMA_zgetrs", "illegal value of N");
@@ -108,7 +107,7 @@ int PLASMA_zgetrs(PLASMA_enum trans, int N, int NRHS,
     }
     if (LDB < max(1, N)) {
         plasma_error("PLASMA_zgetrs", "illegal value of LDB");
-        return -9;
+        return -8;
     }
     /* Quick return */
     if (min(N, NRHS) == 0)
@@ -129,12 +128,6 @@ int PLASMA_zgetrs(PLASMA_enum trans, int N, int NRHS,
 
     plasma_sequence_create(plasma, &sequence);
 
-    descL = plasma_desc_init(
-        PlasmaComplexDouble,
-        IB, NB, IBNB,
-        NT*IB, NT*NB, 0, 0, NT*IB, NT*NB);
-    descL.mat = L;
-
     if ( PLASMA_TRANSLATION == PLASMA_OUTOFPLACE ) {
         plasma_zooplap2tile( descA, A, NB, NB, LDA, N,    0, 0, N, N   , plasma_desc_mat_free(&(descA)) );
         plasma_zooplap2tile( descB, B, NB, NB, LDB, NRHS, 0, 0, N, NRHS, plasma_desc_mat_free(&(descA)); plasma_desc_mat_free(&(descB)));
@@ -144,7 +137,7 @@ int PLASMA_zgetrs(PLASMA_enum trans, int N, int NRHS,
     }
 
     /* Call the tile interface */
-    PLASMA_zgetrs_Tile_Async(&descA, &descL, IPIV, &descB, sequence, &request);
+    PLASMA_zgetrs_Tile_Async(trans, &descA, IPIV, &descB, sequence, &request);
 
     if ( PLASMA_TRANSLATION == PLASMA_OUTOFPLACE ) {
         plasma_zooptile2lap( descB, B, NB, NB, LDB, NRHS );
@@ -175,14 +168,17 @@ int PLASMA_zgetrs(PLASMA_enum trans, int N, int NRHS,
  *
  *******************************************************************************
  *
+ * @param[in] trans
+ *          Intended to specify the the form of the system of equations:
+ *          = PlasmaNoTrans:   A * X = B     (No transpose)
+ *          = PlasmaTrans:     A**T * X = B  (Transpose)
+ *          = PlasmaConjTrans: A**H * X = B  (Conjugate transpose)
+ *
  * @param[in] A
  *          The tile factors L and U from the factorization, computed by PLASMA_zgetrf.
  *
- * @param[in] L
- *          Auxiliary factorization data, related to the tile L factor, computed by PLASMA_zgetrf.
- *
  * @param[in] IPIV
- *          The pivot indices from PLASMA_zgetrf (not equivalent to LAPACK).
+ *          The pivot indices from PLASMA_zgetrf.
  *
  * @param[in,out] B
  *          On entry, the N-by-NRHS matrix of right hand side matrix B.
@@ -203,7 +199,7 @@ int PLASMA_zgetrs(PLASMA_enum trans, int N, int NRHS,
  * @sa PLASMA_zgetrf_Tile
  *
  ******************************************************************************/
-int PLASMA_zgetrs_Tile(PLASMA_desc *A, PLASMA_desc *L, int *IPIV, PLASMA_desc *B)
+int PLASMA_zgetrs_Tile(PLASMA_enum trans, PLASMA_desc *A, int *IPIV, PLASMA_desc *B)
 {
     plasma_context_t *plasma;
     PLASMA_sequence *sequence = NULL;
@@ -216,7 +212,7 @@ int PLASMA_zgetrs_Tile(PLASMA_desc *A, PLASMA_desc *L, int *IPIV, PLASMA_desc *B
         return PLASMA_ERR_NOT_INITIALIZED;
     }
     plasma_sequence_create(plasma, &sequence);
-    PLASMA_zgetrs_Tile_Async(A, L, IPIV, B, sequence, &request);
+    PLASMA_zgetrs_Tile_Async(trans, A, IPIV, B, sequence, &request);
     plasma_dynamic_sync();
     status = sequence->status;
     plasma_sequence_destroy(plasma, sequence);
@@ -252,11 +248,10 @@ int PLASMA_zgetrs_Tile(PLASMA_desc *A, PLASMA_desc *L, int *IPIV, PLASMA_desc *B
  * @sa PLASMA_zgetrf_Tile_Async
  *
  ******************************************************************************/
-int PLASMA_zgetrs_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV, PLASMA_desc *B,
+int PLASMA_zgetrs_Tile_Async(PLASMA_enum trans, PLASMA_desc *A, int *IPIV, PLASMA_desc *B,
                              PLASMA_sequence *sequence, PLASMA_request *request)
 {
     PLASMA_desc descA = *A;
-    PLASMA_desc descL = *L;
     PLASMA_desc descB = *B;
     plasma_context_t *plasma;
 
@@ -284,10 +279,6 @@ int PLASMA_zgetrs_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV, PLASMA_d
         plasma_error("PLASMA_zgetrs_Tile", "invalid first descriptor");
         return plasma_request_fail(sequence, request, PLASMA_ERR_ILLEGAL_VALUE);
     }
-    if (plasma_desc_check(&descL) != PLASMA_SUCCESS) {
-        plasma_error("PLASMA_zgetrs_Tile", "invalid second descriptor");
-        return plasma_request_fail(sequence, request, PLASMA_ERR_ILLEGAL_VALUE);
-    }
     if (plasma_desc_check(&descB) != PLASMA_SUCCESS) {
         plasma_error("PLASMA_zgetrs_Tile", "invalid third descriptor");
         return plasma_request_fail(sequence, request, PLASMA_ERR_ILLEGAL_VALUE);
@@ -302,24 +293,87 @@ int PLASMA_zgetrs_Tile_Async(PLASMA_desc *A, PLASMA_desc *L, int *IPIV, PLASMA_d
     if (min(N, NRHS) == 0)
         return PLASMA_SUCCESS;
 */
-    plasma_parallel_call_6(plasma_pztrsmpl,
-        PLASMA_desc, descA,
-        PLASMA_desc, descB,
-        PLASMA_desc, descL,
-        int*, IPIV,
-        PLASMA_sequence*, sequence,
-        PLASMA_request*, request);
 
-    plasma_parallel_call_9(plasma_pztrsm,
-        PLASMA_enum, PlasmaLeft,
-        PLASMA_enum, PlasmaUpper,
-        PLASMA_enum, PlasmaNoTrans,
-        PLASMA_enum, PlasmaNonUnit,
-        PLASMA_Complex64_t, 1.0,
-        PLASMA_desc, descA,
-        PLASMA_desc, descB,
-        PLASMA_sequence*, sequence,
-        PLASMA_request*, request);
+    if ( trans == PlasmaNoTrans )
+    {
+        plasma_dynamic_call_3(
+            plasma_pzbarrier_tl2pnl,
+            PLASMA_desc, descB,
+            PLASMA_sequence*, sequence,
+            PLASMA_request*,  request);
 
+        /* swap */
+        plasma_dynamic_call_5(
+            plasma_pzlaswp,
+            PLASMA_desc, descB,
+            int *,       IPIV,
+            int,         1,
+            PLASMA_sequence*, sequence,
+            PLASMA_request*,  request);
+
+        plasma_parallel_call_9(
+            plasma_pztrsm,
+            PLASMA_enum, PlasmaLeft,
+            PLASMA_enum, PlasmaLower,
+            PLASMA_enum, PlasmaNoTrans,
+            PLASMA_enum, PlasmaUnit,
+            PLASMA_Complex64_t, 1.0,
+            PLASMA_desc, descA,
+            PLASMA_desc, descB,
+            PLASMA_sequence*, sequence,
+            PLASMA_request*, request);
+
+        plasma_parallel_call_9(
+            plasma_pztrsm,
+            PLASMA_enum, PlasmaLeft,
+            PLASMA_enum, PlasmaUpper,
+            PLASMA_enum, PlasmaNoTrans,
+            PLASMA_enum, PlasmaNonUnit,
+            PLASMA_Complex64_t, 1.0,
+            PLASMA_desc, descA,
+            PLASMA_desc, descB,
+            PLASMA_sequence*, sequence,
+            PLASMA_request*, request);
+    }
+    else {
+        plasma_parallel_call_9(
+            plasma_pztrsm,
+            PLASMA_enum, PlasmaLeft,
+            PLASMA_enum, PlasmaUpper,
+            PLASMA_enum, trans,
+            PLASMA_enum, PlasmaNonUnit,
+            PLASMA_Complex64_t, 1.0,
+            PLASMA_desc, descA,
+            PLASMA_desc, descB,
+            PLASMA_sequence*, sequence,
+            PLASMA_request*, request);
+
+        plasma_parallel_call_9(
+            plasma_pztrsm,
+            PLASMA_enum, PlasmaLeft,
+            PLASMA_enum, PlasmaLower,
+            PLASMA_enum, trans,
+            PLASMA_enum, PlasmaUnit,
+            PLASMA_Complex64_t, 1.0,
+            PLASMA_desc, descA,
+            PLASMA_desc, descB,
+            PLASMA_sequence*, sequence,
+            PLASMA_request*, request);
+
+        /* swap */
+        plasma_dynamic_call_5(
+            plasma_pzlaswp,
+            PLASMA_desc, descB,
+            int *,       IPIV,
+            int,         -1,
+            PLASMA_sequence*, sequence,
+            PLASMA_request*,  request);
+
+        plasma_dynamic_call_3(
+            plasma_pzbarrier_pnl2tl,
+            PLASMA_desc, descB,
+            PLASMA_sequence*, sequence,
+            PLASMA_request*,  request);
+    }
     return PLASMA_SUCCESS;
 }
