@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Hatem Ltaief
  * @author Jakub Kurzak
  * @date 2010-11-15
@@ -43,11 +43,11 @@
  * @param[in] T
  *          Auxiliary factorization data, computed by PLASMA_zgelqf.
  *
- * @param[out] B
+ * @param[out] Q
  *          On exit, the M-by-N matrix Q.
  *
- * @param[in] LDA
- *          The leading dimension of the array B. LDB >= max(1,M).
+ * @param[in] LDQ
+ *          The leading dimension of the array Q. LDQ >= max(1,M).
  *
  *******************************************************************************
  *
@@ -60,22 +60,22 @@
  * @sa PLASMA_zunglq_Tile
  * @sa PLASMA_zunglq_Tile_Async
  * @sa PLASMA_cunglq
- * @sa PLASMA_dunglq
- * @sa PLASMA_sunglq
+ * @sa PLASMA_dorglq
+ * @sa PLASMA_sorglq
  * @sa PLASMA_zgelqf
  *
  ******************************************************************************/
 int PLASMA_zunglq(int M, int N, int K,
                   PLASMA_Complex64_t *A, int LDA,
                   PLASMA_Complex64_t *T,
-                  PLASMA_Complex64_t *B, int LDB)
+                  PLASMA_Complex64_t *Q, int LDQ)
 {
-    int NB, IB, IBNB, MT, NT;
+    int NB, IB, IBNB, KT, NT;
     int status;
     plasma_context_t *plasma;
     PLASMA_sequence *sequence = NULL;
     PLASMA_request request = PLASMA_REQUEST_INITIALIZER;
-    PLASMA_desc descA, descB, descT;
+    PLASMA_desc descA, descQ, descT;
 
     plasma = plasma_context_self();
     if (plasma == NULL) {
@@ -98,12 +98,12 @@ int PLASMA_zunglq(int M, int N, int K,
         plasma_error("PLASMA_zunglq", "illegal value of LDA");
         return -5;
     }
-    if (LDB < max(1, M)) {
-        plasma_error("PLASMA_zunglq", "illegal value of LDB");
+    if (LDQ < max(1, M)) {
+        plasma_error("PLASMA_zunglq", "illegal value of LDQ");
         return -8;
     }
     /* Quick return - currently NOT equivalent to LAPACK's:
-     * CALL DLASET( 'Full', MAX( M, N ), NRHS, ZERO, ZERO, B, LDB ) */
+     * CALL DLASET( 'Full', MAX( M, N ), NRHS, ZERO, ZERO, B, LDQ ) */
     if (min(M, min(N, K)) == 0)
         return PLASMA_SUCCESS;
 
@@ -119,7 +119,7 @@ int PLASMA_zunglq(int M, int N, int K,
     IB   = PLASMA_IB;
     IBNB = IB*NB;
     NT   = (N%NB==0) ? (N/NB) : (N/NB+1);
-    MT   = (M%NB==0) ? (M/NB) : (M/NB+1);
+    KT   = (K%NB==0) ? (K/NB) : (K/NB+1);
 
     plasma_sequence_create(plasma, &sequence);
 
@@ -127,36 +127,36 @@ int PLASMA_zunglq(int M, int N, int K,
         descT = plasma_desc_init(
             PlasmaComplexDouble,
             IB, NB, IBNB,
-            MT*IB, NT*NB, 0, 0, MT*IB, NT*NB);
+            KT*IB, NT*NB, 0, 0, KT*IB, NT*NB);
     }
     else {
         /* Double the size of T to accomodate the tree reduction phase */
         descT = plasma_desc_init(
             PlasmaComplexDouble,
             IB, NB, IBNB,
-            MT*IB, 2*NT*NB, 0, 0, MT*IB, 2*NT*NB);
+            KT*IB, 2*NT*NB, 0, 0, KT*IB, 2*NT*NB);
     }
     descT.mat = T;
 
     if ( PLASMA_TRANSLATION == PLASMA_OUTOFPLACE ) {
         plasma_zooplap2tile( descA, A, NB, NB, LDA, N, 0, 0, K, N, plasma_desc_mat_free(&(descA)) );
-        plasma_zooplap2tile( descB, B, NB, NB, LDB, N, 0, 0, M, N, plasma_desc_mat_free(&(descA)); plasma_desc_mat_free(&(descB)));
+        plasma_zooplap2tile( descQ, Q, NB, NB, LDQ, N, 0, 0, M, N, plasma_desc_mat_free(&(descA)); plasma_desc_mat_free(&(descQ)));
     } else {
         plasma_ziplap2tile( descA, A, NB, NB, LDA, N, 0, 0, K, N);
-        plasma_ziplap2tile( descB, B, NB, NB, LDB, N, 0, 0, M, N);
+        plasma_ziplap2tile( descQ, Q, NB, NB, LDQ, N, 0, 0, M, N);
     }
 
     /* Call the tile interface */
-    PLASMA_zunglq_Tile_Async(&descA, &descT, &descB, sequence, &request);
+    PLASMA_zunglq_Tile_Async(&descA, &descT, &descQ, sequence, &request);
 
     if ( PLASMA_TRANSLATION == PLASMA_OUTOFPLACE ) {
-        plasma_zooptile2lap( descB, B, NB, NB, LDB, N );
+        plasma_zooptile2lap( descQ, Q, NB, NB, LDQ, N );
         plasma_dynamic_sync();
         plasma_desc_mat_free(&descA);
-        plasma_desc_mat_free(&descB);
+        plasma_desc_mat_free(&descQ);
     } else {
         plasma_ziptile2lap( descA, A, NB, NB, LDA, N );
-        plasma_ziptile2lap( descB, B, NB, NB, LDB, N );
+        plasma_ziptile2lap( descQ, Q, NB, NB, LDQ, N );
         plasma_dynamic_sync();
     }
         
@@ -194,8 +194,8 @@ int PLASMA_zunglq(int M, int N, int K,
  * @sa PLASMA_zunglq
  * @sa PLASMA_zunglq_Tile_Async
  * @sa PLASMA_cunglq_Tile
- * @sa PLASMA_dunglq_Tile
- * @sa PLASMA_sunglq_Tile
+ * @sa PLASMA_dorglq_Tile
+ * @sa PLASMA_sorglq_Tile
  * @sa PLASMA_zgelqf_Tile
  *
  ******************************************************************************/
@@ -241,17 +241,17 @@ int PLASMA_zunglq_Tile(PLASMA_desc *A, PLASMA_desc *T, PLASMA_desc *B)
  * @sa PLASMA_zunglq
  * @sa PLASMA_zunglq_Tile
  * @sa PLASMA_cunglq_Tile_Async
- * @sa PLASMA_dunglq_Tile_Async
- * @sa PLASMA_sunglq_Tile_Async
+ * @sa PLASMA_dorglq_Tile_Async
+ * @sa PLASMA_sorglq_Tile_Async
  * @sa PLASMA_zgelqf_Tile_Async
  *
  ******************************************************************************/
-int PLASMA_zunglq_Tile_Async(PLASMA_desc *A, PLASMA_desc *T, PLASMA_desc *B,
+int PLASMA_zunglq_Tile_Async(PLASMA_desc *A, PLASMA_desc *T, PLASMA_desc *Q,
                              PLASMA_sequence *sequence, PLASMA_request *request)
 {
     PLASMA_desc descA = *A;
     PLASMA_desc descT = *T;
-    PLASMA_desc descB = *B;
+    PLASMA_desc descQ = *Q;
     plasma_context_t *plasma;
 
     plasma = plasma_context_self();
@@ -282,17 +282,17 @@ int PLASMA_zunglq_Tile_Async(PLASMA_desc *A, PLASMA_desc *T, PLASMA_desc *B,
         plasma_error("PLASMA_zunglq_Tile", "invalid second descriptor");
         return plasma_request_fail(sequence, request, PLASMA_ERR_ILLEGAL_VALUE);
     }
-    if (plasma_desc_check(&descB) != PLASMA_SUCCESS) {
+    if (plasma_desc_check(&descQ) != PLASMA_SUCCESS) {
         plasma_error("PLASMA_zunglq_Tile", "invalid third descriptor");
         return plasma_request_fail(sequence, request, PLASMA_ERR_ILLEGAL_VALUE);
     }
     /* Check input arguments */
-    if (descA.nb != descA.mb || descB.nb != descB.mb) {
+    if (descA.nb != descA.mb || descQ.nb != descQ.mb) {
         plasma_error("PLASMA_zunglq_Tile", "only square tiles supported");
         return plasma_request_fail(sequence, request, PLASMA_ERR_ILLEGAL_VALUE);
     }
     /* Quick return - currently NOT equivalent to LAPACK's:
-     * CALL DLASET( 'Full', MAX( M, N ), NRHS, ZERO, ZERO, B, LDB ) */
+     * CALL DLASET( 'Full', MAX( M, N ), NRHS, ZERO, ZERO, Q, LDQ ) */
 /*
     if (min(M, N) == 0)
         return PLASMA_SUCCESS;
@@ -300,7 +300,7 @@ int PLASMA_zunglq_Tile_Async(PLASMA_desc *A, PLASMA_desc *T, PLASMA_desc *B,
     if (plasma->householder == PLASMA_FLAT_HOUSEHOLDER) {
         plasma_dynamic_call_5(plasma_pzunglq,
             PLASMA_desc, descA,
-            PLASMA_desc, descB,
+            PLASMA_desc, descQ,
             PLASMA_desc, descT,
             PLASMA_sequence*, sequence,
             PLASMA_request*, request);
@@ -308,7 +308,7 @@ int PLASMA_zunglq_Tile_Async(PLASMA_desc *A, PLASMA_desc *T, PLASMA_desc *B,
     else {
         plasma_dynamic_call_6(plasma_pzunglqrh,
             PLASMA_desc, descA,
-            PLASMA_desc, descB,
+            PLASMA_desc, descQ,
             PLASMA_desc, descT,
             PLASMA_enum, PLASMA_RHBLK,
             PLASMA_sequence*, sequence,
