@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Hatem Ltaief
  * @author Jakub Kurzak
  * @date 2010-11-15
@@ -60,8 +60,8 @@
  * @sa PLASMA_zungqr_Tile
  * @sa PLASMA_zungqr_Tile_Async
  * @sa PLASMA_cungqr
- * @sa PLASMA_dungqr
- * @sa PLASMA_sungqr
+ * @sa PLASMA_dorgqr
+ * @sa PLASMA_sorgqr
  * @sa PLASMA_zgeqrf
  *
  ******************************************************************************/
@@ -70,7 +70,7 @@ int PLASMA_zungqr(int M, int N, int K,
                   PLASMA_Complex64_t *T,
                   PLASMA_Complex64_t *Q, int LDQ)
 {
-    int NB, IB, IBNB, MT, NT;
+    int NB, IB, IBNB, MT, KT;
     int status;
     plasma_context_t *plasma;
     PLASMA_sequence *sequence = NULL;
@@ -112,12 +112,12 @@ int PLASMA_zungqr(int M, int N, int K,
         return status;
     }
 
-    /* Set MT & NT */
+    /* Set MT & KT */
     NB   = PLASMA_NB;
     IB   = PLASMA_IB;
     IBNB = IB*NB;
     MT   = (M%NB==0) ? (M/NB) : (M/NB+1);
-    NT   = (N%NB==0) ? (N/NB) : (N/NB+1);
+    KT   = (K%NB==0) ? (K/NB) : (K/NB+1);
 
     plasma_sequence_create(plasma, &sequence);
 
@@ -125,14 +125,14 @@ int PLASMA_zungqr(int M, int N, int K,
         descT = plasma_desc_init(
             PlasmaComplexDouble,
             IB, NB, IBNB,
-            MT*IB, NT*NB, 0, 0, MT*IB, NT*NB);
+            MT*IB, KT*NB, 0, 0, MT*IB, KT*NB);
     }
     else {
         /* Double the size of T to accomodate the tree reduction phase */
         descT = plasma_desc_init(
             PlasmaComplexDouble,
             IB, NB, IBNB,
-            MT*IB, 2*NT*NB, 0, 0, MT*IB, 2*NT*NB);
+            MT*IB, 2*KT*NB, 0, 0, MT*IB, 2*KT*NB);
     }
     descT.mat = T;
 
@@ -192,8 +192,8 @@ int PLASMA_zungqr(int M, int N, int K,
  * @sa PLASMA_zungqr
  * @sa PLASMA_zungqr_Tile_Async
  * @sa PLASMA_cungqr_Tile
- * @sa PLASMA_dungqr_Tile
- * @sa PLASMA_sungqr_Tile
+ * @sa PLASMA_dorgqr_Tile
+ * @sa PLASMA_sorgqr_Tile
  * @sa PLASMA_zgeqrf_Tile
  *
  ******************************************************************************/
@@ -239,8 +239,8 @@ int PLASMA_zungqr_Tile(PLASMA_desc *A, PLASMA_desc *T, PLASMA_desc *Q)
  * @sa PLASMA_zungqr
  * @sa PLASMA_zungqr_Tile
  * @sa PLASMA_cungqr_Tile_Async
- * @sa PLASMA_dungqr_Tile_Async
- * @sa PLASMA_sungqr_Tile_Async
+ * @sa PLASMA_dorgqr_Tile_Async
+ * @sa PLASMA_sorgqr_Tile_Async
  * @sa PLASMA_zgeqrf_Tile_Async
  *
  ******************************************************************************/
