@@ -6,9 +6,10 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Hatem Ltaief
  * @author Jakub Kurzak
+ * @author Dulceneia Becker
  * @date 2010-11-15
  * @precisions normal z -> s d c
  *
@@ -74,8 +75,8 @@
  * @sa PLASMA_zunmlq_Tile
  * @sa PLASMA_zunmlq_Tile_Async
  * @sa PLASMA_cunmlq
- * @sa PLASMA_dunmlq
- * @sa PLASMA_sunmlq
+ * @sa PLASMA_dormlq
+ * @sa PLASMA_sormlq
  * @sa PLASMA_zgelqf
  *
  ******************************************************************************/
@@ -84,7 +85,7 @@ int PLASMA_zunmlq(PLASMA_enum side, PLASMA_enum trans, int M, int N, int K,
                   PLASMA_Complex64_t *T,
                   PLASMA_Complex64_t *B, int LDB)
 {
-    int NB, IB, IBNB, MT, KT;
+    int NB, IB, IBNB, KT, NT, An;
     int status;
     plasma_context_t *plasma;
     PLASMA_sequence *sequence = NULL;
@@ -96,14 +97,20 @@ int PLASMA_zunmlq(PLASMA_enum side, PLASMA_enum trans, int M, int N, int K,
         plasma_fatal_error("PLASMA_zunmlq", "PLASMA not initialized");
         return PLASMA_ERR_NOT_INITIALIZED;
     }
+
+    if (side == PlasmaLeft)
+        An = M;
+    else 
+        An = N;
+
     /* Check input arguments */
-    if (side != PlasmaLeft) {
-        plasma_error("PLASMA_zunmlq", "only PlasmaLeft supported");
-        return PLASMA_ERR_NOT_SUPPORTED;
+    if ( (side != PlasmaLeft) && (side != PlasmaRight) ) {
+        plasma_error("PLASMA_zunmlq", "illegal value of side");
+        return -1;
     }
-    if (trans != PlasmaConjTrans) {
-        plasma_error("PLASMA_zunmlq", "only PlasmaConjTrans supported");
-        return PLASMA_ERR_NOT_SUPPORTED;
+    if ( (trans != PlasmaConjTrans) && (trans != PlasmaNoTrans) ){
+        plasma_error("PLASMA_zunmlq", "illegal value of trans");
+        return -2;
     }
     if (M < 0) {
         plasma_error("PLASMA_zunmlq", "illegal value of M");
@@ -113,7 +120,7 @@ int PLASMA_zunmlq(PLASMA_enum side, PLASMA_enum trans, int M, int N, int K,
         plasma_error("PLASMA_zunmlq", "illegal value of N");
         return -4;
     }
-    if (K < 0) {
+    if ((K < 0) || (K > An)) {
         plasma_error("PLASMA_zunmlq", "illegal value of K");
         return -5;
     }
@@ -141,8 +148,8 @@ int PLASMA_zunmlq(PLASMA_enum side, PLASMA_enum trans, int M, int N, int K,
     NB   = PLASMA_NB;
     IB   = PLASMA_IB;
     IBNB = IB*NB;
-    MT   = (M%NB==0) ? (M/NB) : (M/NB+1);
-    KT   = (K%NB==0) ? (K/NB) : (K/NB+1);
+    KT   = ( K%NB==0) ? (K /NB) : (K /NB+1);
+    NT   = (An%NB==0) ? (An/NB) : (An/NB+1);
 
     plasma_sequence_create(plasma, &sequence);
 
@@ -150,28 +157,28 @@ int PLASMA_zunmlq(PLASMA_enum side, PLASMA_enum trans, int M, int N, int K,
         descT = plasma_desc_init(
             PlasmaComplexDouble,
             IB, NB, IBNB,
-            KT*IB, MT*NB, 0, 0, KT*IB, MT*NB);
+            KT*IB, NT*NB, 0, 0, KT*IB, NT*NB);
     }
     else {
         /* Double the size of T to accomodate the tree reduction phase */
         descT = plasma_desc_init(
             PlasmaComplexDouble,
             IB, NB, IBNB,
-            KT*IB, 2*MT*NB, 0, 0, KT*IB, 2*KT*NB);
+            KT*IB, 2*NT*NB, 0, 0, KT*IB, 2*NT*NB);
     }
     descT.mat = T;
 
     if ( PLASMA_TRANSLATION == PLASMA_OUTOFPLACE ) {
-        plasma_zooplap2tile( descA, A, NB, NB, LDA, M, 0, 0, K, M, plasma_desc_mat_free(&(descA)) );
-        plasma_zooplap2tile( descB, B, NB, NB, LDB, N, 0, 0, M, N, plasma_desc_mat_free(&(descA)); plasma_desc_mat_free(&(descB)));
+        plasma_zooplap2tile( descA, A, NB, NB, LDA, An, 0, 0, K, An, plasma_desc_mat_free(&(descA)) );
+        plasma_zooplap2tile( descB, B, NB, NB, LDB, N,  0, 0, M, N,  plasma_desc_mat_free(&(descA)); plasma_desc_mat_free(&(descB)));
     } else {
-        plasma_ziplap2tile( descA, A, NB, NB, LDA, M, 0, 0, K, M);
-        plasma_ziplap2tile( descB, B, NB, NB, LDB, N, 0, 0, M, N);
+        plasma_ziplap2tile( descA, A, NB, NB, LDA, An, 0, 0, K, An);
+        plasma_ziplap2tile( descB, B, NB, NB, LDB, N,  0, 0, M, N);
     }
 
     /* Call the tile interface */
     PLASMA_zunmlq_Tile_Async(
-        PlasmaLeft, PlasmaConjTrans, &descA, &descT, &descB, sequence, &request);
+        side, trans, &descA, &descT, &descB, sequence, &request);
 
     if ( PLASMA_TRANSLATION == PLASMA_OUTOFPLACE ) {
         plasma_zooptile2lap( descB, B, NB, NB, LDB, N );
@@ -179,7 +186,7 @@ int PLASMA_zunmlq(PLASMA_enum side, PLASMA_enum trans, int M, int N, int K,
         plasma_desc_mat_free(&descA);
         plasma_desc_mat_free(&descB);
     } else {
-        plasma_ziptile2lap( descA, A, NB, NB, LDA, M );
+        plasma_ziptile2lap( descA, A, NB, NB, LDA, An );
         plasma_ziptile2lap( descB, B, NB, NB, LDB, N );
         plasma_dynamic_sync();
     }
@@ -232,8 +239,8 @@ int PLASMA_zunmlq(PLASMA_enum side, PLASMA_enum trans, int M, int N, int K,
  * @sa PLASMA_zunmlq
  * @sa PLASMA_zunmlq_Tile_Async
  * @sa PLASMA_cunmlq_Tile
- * @sa PLASMA_dunmlq_Tile
- * @sa PLASMA_sunmlq_Tile
+ * @sa PLASMA_dormlq_Tile
+ * @sa PLASMA_sormlq_Tile
  * @sa PLASMA_zgelqf_Tile
  *
  ******************************************************************************/
@@ -280,8 +287,8 @@ int PLASMA_zunmlq_Tile(PLASMA_enum side, PLASMA_enum trans,
  * @sa PLASMA_zunmlq
  * @sa PLASMA_zunmlq_Tile
  * @sa PLASMA_cunmlq_Tile_Async
- * @sa PLASMA_dunmlq_Tile_Async
- * @sa PLASMA_sunmlq_Tile_Async
+ * @sa PLASMA_dormlq_Tile_Async
+ * @sa PLASMA_sormlq_Tile_Async
  * @sa PLASMA_zgelqf_Tile_Async
  *
  ******************************************************************************/
@@ -331,13 +338,11 @@ int PLASMA_zunmlq_Tile_Async(PLASMA_enum side, PLASMA_enum trans,
         plasma_error("PLASMA_zunmlq_Tile", "only square tiles supported");
         return plasma_request_fail(sequence, request, PLASMA_ERR_ILLEGAL_VALUE);
     }
-    if (side != PlasmaLeft) {
-        plasma_error("PLASMA_zunmlq_Tile", "only PlasmaLeft supported");
-        return plasma_request_fail(sequence, request, PLASMA_ERR_NOT_SUPPORTED);
+    if ( (side != PlasmaLeft) && (side != PlasmaRight) ) {
+        return plasma_request_fail(sequence, request, PLASMA_ERR_ILLEGAL_VALUE);
     }
-    if (trans != PlasmaConjTrans) {
-        plasma_error("PLASMA_zunmlq_Tile", "only PlasmaConjTrans supported");
-        return plasma_request_fail(sequence, request, PLASMA_ERR_NOT_SUPPORTED);
+    if ( (trans != PlasmaConjTrans) && (trans != PlasmaNoTrans) ){
+        return plasma_request_fail(sequence, request, PLASMA_ERR_ILLEGAL_VALUE);
     }
     /* Quick return - currently NOT equivalent to LAPACK's:
      * CALL DLASET( 'Full', MAX( M, N ), NRHS, ZERO, ZERO, B, LDB ) */
@@ -346,15 +351,31 @@ int PLASMA_zunmlq_Tile_Async(PLASMA_enum side, PLASMA_enum trans,
         return PLASMA_SUCCESS;
 */
     if (plasma->householder == PLASMA_FLAT_HOUSEHOLDER) {
-        plasma_parallel_call_5(plasma_pzunmlq,
-            PLASMA_desc, descA,
-            PLASMA_desc, descB,
-            PLASMA_desc, descT,
-            PLASMA_sequence*, sequence,
-            PLASMA_request*, request);
+        if ( (trans == PlasmaConjTrans) &&
+             (side == PlasmaLeft) ) {
+            plasma_parallel_call_7(plasma_pzunmlq,
+                PLASMA_enum, side,
+                PLASMA_enum, trans,
+                PLASMA_desc, descA,
+                PLASMA_desc, descB,
+                PLASMA_desc, descT,
+                PLASMA_sequence*, sequence,
+                PLASMA_request*, request);
+        } else {
+            plasma_dynamic_call_7(plasma_pzunmlq,
+                PLASMA_enum, side,
+                PLASMA_enum, trans,
+                PLASMA_desc, descA,
+                PLASMA_desc, descB,
+                PLASMA_desc, descT,
+                PLASMA_sequence*, sequence,
+                PLASMA_request*, request);
+        }
     }
     else {
-        plasma_dynamic_call_6(plasma_pzunmlqrh,
+        plasma_dynamic_call_8(plasma_pzunmlqrh,
+            PLASMA_enum, side,
+            PLASMA_enum, trans,
             PLASMA_desc, descA,
             PLASMA_desc, descB,
             PLASMA_desc, descT,
