@@ -6,8 +6,9 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Jakub Kurzak
+ * @author Mathieu Faverge
  * @date 2010-11-15
  *
  **/
@@ -29,12 +30,39 @@
 #include "context.h"
 #include "control.h"
 #include "core_blas.h"
+#include "core_blas_dag.h"
 #include "allocate.h"
 #include "auxiliary.h"
 #include "descriptor.h"
 #include "tile.h"
 #include "async.h"
 
+/** ****************************************************************************
+ *  Determine if weak symbol are allowed 
+ */
+#if defined(linux) || defined(__linux) || defined(__linux__)
+#if defined(__GNUC_EXCL__) || defined(__GNUC__) 
+#define PLASMA_HAVE_WEAK 1
+#endif
+#endif
+
+/** ****************************************************************************
+ *  Determine FORTRAN names
+ */
+#if defined(ADD_)
+#define PLASMA_FNAME(lcname, UCNAME)        plasma_##lcname##_
+#define PLASMA_TILE_FNAME(lcname, UCNAME)   plasma_tile_##lcname##_
+#define PLASMA_ASYNC_FNAME(lcname, UCNAME)  plasma_tile_async_##lcname##_
+#elif defined(NOCHANGE)
+#define PLASMA_FNAME(lcname, UCNAME)        plasma_##lcname
+#define PLASMA_TILE_FNAME(lcname, UCNAME)   plasma_tile_##lcname##
+#define PLASMA_ASYNC_FNAME(lcname, UCNAME)  plasma_tile_async_##lcname##
+#elif defined(UPCASE)
+#define PLASMA_FNAME(lcname, UCNAME)        PLASMA_##UCNAME
+#define PLASMA_TILE_FNAME(lcname, UCNAME)   PLASMA_TILE_##UCNAME##
+#define PLASMA_ASYNC_FNAME(lcname, UCNAME)  PLASMA_TILE_ASYNC_##UCNAME##
+#endif
+
 /***************************************************************************//**
  *  Global shortcuts
  **/
@@ -45,7 +73,6 @@
 #define PLASMA_IB          plasma->ib
 #define PLASMA_NBNBSIZE    plasma->nbnbsize
 #define PLASMA_IBNBSIZE    plasma->ibnbsize
-#define PLASMA_INFO        plasma->info
 #define PLASMA_SCHEDULING  plasma->scheduling
 #define PLASMA_RHBLK       plasma->rhblock
 #define PLASMA_TRANSLATION plasma->translation
