@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Jakub Kurzak
  * @date 2010-11-15
  *
@@ -56,10 +56,9 @@ plasma_context_t *plasma_context_create()
     plasma->nbnbsize = 16384;
     plasma->ibnbsize = 4096;
     plasma->rhblock = 4;
-    plasma->info = 0;
 
-    plasma->errors_enabled     = PLASMA_FALSE;
-    plasma->warnings_enabled   = PLASMA_FALSE;
+    plasma->errors_enabled     = PLASMA_TRUE;
+    plasma->warnings_enabled   = PLASMA_TRUE;
     plasma->autotuning_enabled = PLASMA_TRUE;
     plasma->dynamic_section    = PLASMA_FALSE;
 
@@ -253,8 +252,9 @@ int PLASMA_Disable(PLASMA_enum lever)
  *          Feature to be enabled:
  *          @arg PLASMA_TILE_SIZE:        size matrix tile,
  *          @arg PLASMA_INNER_BLOCK_SIZE: size of tile inner block,
- *          @arg PLASMA_SCHEDULING:       type of scheduling
+ *          @arg PLASMA_SCHEDULING_MODE:  type of scheduling
  *                  (PLASMA_STATIC_SCHEDULING or PLASMA_DYNAMIC_SCHEDULING).
+ *          @arg PLASMA_INNER_BANDWIDTH:  matrix bandwidth size
  *
  * @param[in] value
  *          Value of the parameter.
@@ -287,6 +287,12 @@ int PLASMA_Set(PLASMA_enum param, int value)
             plasma->ibnbsize = plasma->ib * plasma->nb; // * sizeof(float);
 //          plasma->nbnbsize = roundup(plasma->nbnbsize, CACHE_LINE_SIZE);
 //          plasma->nbnbsize /= sizeof(float);
+            if ( plasma->autotuning_enabled ) {
+                plasma->autotuning_enabled = PLASMA_FALSE;
+                plasma_warning("PLASMA_Set", "autotuning has been automatically disabled\n");
+            }
+            /* Limit ib to nb */
+            plasma->ib = min( plasma->nb, plasma->ib );
             break;
         case PLASMA_INNER_BLOCK_SIZE:
             if (value <= 0) {
@@ -297,16 +303,21 @@ int PLASMA_Set(PLASMA_enum param, int value)
                 plasma_error("PLASMA_Set", "inner block larger than tile");
                 return PLASMA_ERR_ILLEGAL_VALUE;
             }
-            if (plasma->nb % value != 0) {
-                plasma_error("PLASMA_Set", "inner block does not divide tile");
-                return PLASMA_ERR_ILLEGAL_VALUE;
-            }
+            /* if (plasma->nb % value != 0) { */
+            /*     plasma_error("PLASMA_Set", "inner block does not divide tile"); */
+            /*     return PLASMA_ERR_ILLEGAL_VALUE; */
+            /* } */
             plasma->ib = value;
             /* Calculate T, L tile size and round up to cache line size */
             /* round up for the smallest type (float) - will hold for all */
             plasma->ibnbsize = plasma->ib * plasma->nb; // * sizeof(float);
 //          plasma->ibnbsize = roundup(plasma->ibnbsize, CACHE_LINE_SIZE);
 //          plasma->ibnbsize /= sizeof(float);
+
+            if ( plasma->autotuning_enabled ) {
+                plasma->autotuning_enabled = PLASMA_FALSE;
+                plasma_warning("PLASMA_Set", "autotuning has been automatically disabled\n");
+            }
             break;
         case PLASMA_SCHEDULING_MODE:
             if (value != PLASMA_STATIC_SCHEDULING && value != PLASMA_DYNAMIC_SCHEDULING) {
