@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Jakub Kurzak
  * @date 2010-11-15
  *
@@ -56,8 +56,6 @@ typedef struct plasma_context_struct {
     int ib;
     int nbnbsize;   // tile size in elements (possibly padded)
     int ibnbsize;   // T or L tile size in elements (---''---)
-    int info;
-    int iinfo;
     int rhblock;    // block size for tree-based (reduction) Householder
 
     /* Barrier implementation */
