@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Jakub Kurzak
  * @date 2010-11-15
  *
@@ -16,33 +16,6 @@
 #include "descriptor.h"
 
 #include <stdlib.h>
-
-/***************************************************************************//**
- *  Internal function to return adress of block (m,n)
- **/
-void *plasma_getaddr(PLASMA_desc A, int m, int n)
-{
-    size_t mm = m+A.i/A.mb;
-    size_t nn = n+A.j/A.nb;
-    size_t eltsize = plasma_element_size(A.dtyp);
-    size_t offset = 0;
-
-    if (mm < A.lm1) {
-        if (nn < A.ln1)
-            offset = A.bsiz*(mm+A.lm1*nn);
-        else
-            offset = A.A12 + (A.mb*(A.ln%A.nb)*mm);
-    }
-    else {
-        if (nn < A.ln1)
-            offset = A.A21 + ((A.lm%A.mb)*A.nb*nn);
-        else
-            offset = A.A22;
-    }
-
-    return (void*)((intptr_t)A.mat + (offset*eltsize) );
-}
-
 /***************************************************************************//**
  *  Internal static descriptor initializer
  **/
@@ -149,11 +122,13 @@ int plasma_desc_mat_alloc(PLASMA_desc *desc)
 {
     size_t size;
 
-    size = desc->lm*desc->ln*plasma_element_size(desc->dtyp);
+    size = (size_t)desc->lm * (size_t)desc->ln * (size_t)plasma_element_size(desc->dtyp);
     if ((desc->mat = malloc(size)) == NULL) {
         plasma_error("plasma_desc_mat_alloc", "malloc() failed");
         return PLASMA_ERR_OUT_OF_RESOURCES;
     }
+
+    memset(desc->mat, 0, size );
     return PLASMA_SUCCESS;
 }
 
