@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Jakub Kurzak
  * @author Piotr Luszczek
  * @date 2010-11-15
@@ -89,6 +89,38 @@
 #define PLASMA_FUNC_ZSYRK   32
 #define PLASMA_FUNC_CHEMM   33
 #define PLASMA_FUNC_ZHEMM   34
+#define PLASMA_FUNC_ZHEEV   35
+#define PLASMA_FUNC_CHEEV   36
+#define PLASMA_FUNC_DSYEV   37
+#define PLASMA_FUNC_SSYEV   38
+#define PLASMA_FUNC_ZHEGST  39
+#define PLASMA_FUNC_CHEGST  40
+#define PLASMA_FUNC_DSYGST  41
+#define PLASMA_FUNC_SSYGST  42
+#define PLASMA_FUNC_ZHEGV   43
+#define PLASMA_FUNC_CHEGV   44
+#define PLASMA_FUNC_DSYGV   45
+#define PLASMA_FUNC_SSYGV   46
+#define PLASMA_FUNC_ZHETRD  47
+#define PLASMA_FUNC_CHETRD  48
+#define PLASMA_FUNC_DSYTRD  49
+#define PLASMA_FUNC_SSYTRD  50
+#define PLASMA_FUNC_ZGESVD  51
+#define PLASMA_FUNC_CGESVD  52
+#define PLASMA_FUNC_DGESVD  53
+#define PLASMA_FUNC_SGESVD  54
+#define PLASMA_FUNC_ZGEEV   55
+#define PLASMA_FUNC_CGEEV   56
+#define PLASMA_FUNC_DGEEV   57
+#define PLASMA_FUNC_SGEEV   58
+#define PLASMA_FUNC_ZGEHRD  59
+#define PLASMA_FUNC_CGEHRD  60
+#define PLASMA_FUNC_DGEHRD  61
+#define PLASMA_FUNC_SGEHRD  62
+#define PLASMA_FUNC_ZGEBRD  63
+#define PLASMA_FUNC_CGEBRD  64
+#define PLASMA_FUNC_DGEBRD  65
+#define PLASMA_FUNC_SGEBRD  66
 
 /***************************************************************************//**
  *  Parallel function call - packing of arguments
