@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.3.1
+ * @version 2.4.0
  * @author Piotr Luszczek
  * @author Mathieu Faverge
  * @date 2010-11-15
@@ -83,15 +83,23 @@ int plasma_setaffinity(int rank) {
         return PLASMA_ERR_UNEXPECTED;
     
     /* Get a copy of its cpuset that we may modify.  */
-    cpuset = hwloc_cpuset_dup(obj->cpuset);
-    
     /* Get only one logical processor (in case the core is SMT/hyperthreaded).  */
+#if !defined(HAVE_HWLOC_BITMAP)
+    cpuset = hwloc_cpuset_dup(obj->cpuset);
     hwloc_cpuset_singlify(cpuset);
-    
+#else
+    cpuset = hwloc_bitmap_dup(obj->cpuset);
+    hwloc_bitmap_singlify(cpuset);
+#endif
+   
     /* And try to bind ourself there.  */
     if (hwloc_set_cpubind(plasma_topology, cpuset, HWLOC_CPUBIND_THREAD)) {
         char *str = NULL;
+#if !defined(HAVE_HWLOC_BITMAP)
         hwloc_cpuset_asprintf(&str, obj->cpuset);
+#else
+        hwloc_bitmap_asprintf(&str, obj->cpuset);
+#endif
         printf("Couldn't bind to cpuset %s\n", str);
         free(str);
         return PLASMA_ERR_UNEXPECTED;
@@ -101,8 +109,11 @@ int plasma_setaffinity(int rank) {
     rank = obj->children[0]->os_index;
     
     /* Free our cpuset copy */
+#if !defined(HAVE_HWLOC_BITMAP)
     hwloc_cpuset_free(cpuset);
-    
+#else
+    hwloc_bitmap_free(cpuset);
+#endif
     return PLASMA_SUCCESS;
 }
 
@@ -115,7 +126,11 @@ int plasma_getnuma_size() {
 
     /* Get a copy of its cpuset that we may modify.  */
     if (obj != NULL) {
+#if !defined(HAVE_HWLOC_BITMAP)
       cpuset = hwloc_cpuset_dup(obj->cpuset);
+#else
+      cpuset = hwloc_bitmap_dup(obj->cpuset);
+#endif
       thrdnbr = hwloc_get_nbobjs_inside_cpuset_by_type(plasma_topology, cpuset, HWLOC_OBJ_CORE);
     }
 
